@@ -20,7 +20,9 @@
  *
  */
 
-/* $Id: calendar-conduit.c,v 1.29 2000/12/03 03:26:46 eskil Exp $ */
+/* $Id: calendar-conduit.c,v 1.34 2002/03/10 20:53:32 srittau Exp $ */
+
+#define G_LOG_DOMAIN "gcalconduit" 
 
 #include <glib.h>
 #include <gnome.h>
@@ -67,26 +69,37 @@ GnomePilotConduit * conduit_get_gpilot_conduit (guint32);
 void conduit_destroy_gpilot_conduit (GnomePilotConduit*);
 void local_record_from_icalobject(GCalLocalRecord *local,iCalObject *obj); 
 
-#define CONDUIT_VERSION "0.8.13"
+#define OBJ_DATA_CONFIG  "gcalconduit_cfg"
 
-#ifdef G_LOG_DOMAIN
-#undef G_LOG_DOMAIN
-#endif
-#define G_LOG_DOMAIN "gcalconduit" 
+#define GET_CONDUIT_CFG(s) ((ConduitCfg*)gtk_object_get_data(GTK_OBJECT(s),OBJ_DATA_CONFIG))
 
-#define DEBUG_CALCONDUIT 
-#undef DEBUG_CALCONDUIT
+#define CONDUIT_VERSION "0.9"
+
+/* #define DEBUG_CALCONDUIT */
+
+#ifdef __GNUC__
+#    if defined(DEBUG_CALCONDUIT)
+#        define LOG(e...) g_log(G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE, e)
+#    else /* !DEBUG_CALCONDUIT */
+#        define LOG(e...)
+#    endif /* DEBUG_CALCONDUIT */
+#else /* !__GNUC__ */
+static void LOG(gchar *mesg, ...);
+#endif /* __GNUC__ */
 
 #ifdef DEBUG_CALCONDUIT
-#define show_exception(e) g_warning ("Exception: %s\n", CORBA_exception_id (e))
-#define LOG(e...) g_log(G_LOG_DOMAIN,G_LOG_LEVEL_MESSAGE, e)
+#    define show_exception(e) g_warning ("Exception: %s\n", CORBA_exception_id (e))
 #else
-#define show_exception(e)
-#define LOG(e...)
+#    define show_exception(e)
 #endif 
 
-#define WARN(e...) g_log(G_LOG_DOMAIN,G_LOG_LEVEL_WARNING, e)
-#define INFO(e...) g_log(G_LOG_DOMAIN,G_LOG_LEVEL_MESSAGE, e)
+#ifdef __GNUC__
+#    define WARN(e...) g_log(G_LOG_DOMAIN,G_LOG_LEVEL_WARNING, e)
+#    define INFO(e...) g_log(G_LOG_DOMAIN,G_LOG_LEVEL_MESSAGE, e)
+#else /* !__GNUC__ */
+static void WARN(gchar *mesg, ...);
+static void INFO(gchar *mesg, ...);
+#endif /* __GNUC__ */
 
 #define catch_ret_val(_env,ret)                                                                 \
   if (_env._major != CORBA_NO_EXCEPTION) {                                                      \
@@ -380,21 +393,25 @@ ical_from_remote_record(GnomePilotConduitStandardAbs *conduit,
 	 * Begin and end
 	 */
 
+	obj->allday = FALSE;
 	if (a.event)
 	{
 		char *tmp;
-		/* turn No-Time events into events at 8 o'clock with a ALLDAY: marking */
+		/* turn No-Time events into events at spanning all day with a text marking */
+		/* Ideally, I should use the gnomecal settings here, which has a day-begin/end,
+		   but watch me not care... */
 		a.begin.tm_sec = 0;
 		a.begin.tm_min = 0;
-		a.begin.tm_hour = 8;
+		a.begin.tm_hour = 0;
 
-		a.end.tm_sec = 0;
-		a.end.tm_min = 0;
-		a.end.tm_hour = 9;
-		tmp = g_strdup_printf ("ALLDAY: %s", obj->summary);
+		a.end.tm_sec = 59;
+		a.end.tm_min = 59;
+		a.end.tm_hour = 23;		
+		tmp = g_strdup_printf ("%s", obj->summary);
 		g_free (obj->summary);
 		obj->summary = tmp;
-	}
+		obj->allday = TRUE;
+	} 
 	
 	obj->dtstart = mktime (&a.begin);
 	obj->dtend = mktime (&a.end);
@@ -603,7 +620,7 @@ check_for_slow_setting(GnomePilotConduit *c,
 		LOG (_("Calendar holds %d entries"),entry_number);
 		/* If the local base is empty, do a slow sync */
 		if ( entry_number <= 0) {
-			gnome_pilot_conduit_standard_set_slow(GNOME_PILOT_CONDUIT_STANDARD(c));
+			gnome_pilot_conduit_standard_set_slow(GNOME_PILOT_CONDUIT_STANDARD(c), TRUE);
 		}
 	}
 }
@@ -761,18 +778,6 @@ store_remote (GnomePilotConduitStandardAbs *conduit,
 	return update_record(conduit,remote,ctxt);
 }
 
-static gint
-clear_status_archive_local (GnomePilotConduitStandardAbs *conduit,
-			    GCalLocalRecord *local,
-			    GCalConduitContext *ctxt)
-{
-	LOG ("entering clear_status_archive_local");
-
-	g_return_val_if_fail(local!=NULL,-1);
-
-        return -1;
-}
-
 static gint
 iterate (GnomePilotConduitStandardAbs *conduit,
 	 GCalLocalRecord **local,
@@ -996,7 +1001,11 @@ transmit (GnomePilotConduitStandardAbs *conduit,
 
 	local->a = g_new0(struct Appointment,1);
 
-	local->a->event = 0; /* if no start time, leave at 1 */
+	local->a->event = 0;
+	/* If all day event, set event to 1, otherwise, set begin/end */
+	if (&local->ical->allday) {
+		local->a->event = 1;
+	}
 	local->a->begin = *localtime(&local->ical->dtstart);
 	local->a->end = *localtime(&local->ical->dtend);
 
@@ -1077,13 +1086,16 @@ transmit (GnomePilotConduitStandardAbs *conduit,
 		local->a->exception = NULL;
 	}
 
-	/* STOP: don't replace these with g_strdup, since free_Appointment
-	   uses free to deallocte */
-	local->a->note = 
-		local->ical->comment==NULL?NULL:strdup(local->ical->comment);
-	local->a->description = 
-		local->ical->summary==NULL?NULL:strdup(local->ical->summary);
-
+	{
+		/* STOP: don't replace these with g_strdup, since free_Appointment
+		   uses free to deallocte */
+		local->a->note = 
+			local->ical->comment==NULL?NULL:strdup(local->ical->comment);
+		
+		local->a->description = 
+			local->ical->summary==NULL?NULL:strdup(local->ical->summary);				
+	}
+		
 	/* Generate pilot record structure */
 	p->record = g_new0(char,0xffff);
 	p->length = pack_Appointment(local->a,p->record,0xffff);
@@ -1414,10 +1426,10 @@ conduit_get_gpilot_conduit (guint32 pilotId)
 
 	retval = gnome_pilot_conduit_standard_abs_new ("DatebookDB", 0x64617465);
 	g_assert (retval != NULL);
-	gnome_pilot_conduit_construct(GNOME_PILOT_CONDUIT(retval),"GnomeCalConduit");
 
 	gcalconduit_load_configuration(&cfg,pilotId);
-	gtk_object_set_data(retval,"gcalconduit_cfg",cfg);
+
+	gtk_object_set_data(retval, OBJ_DATA_CONFIG, cfg);
 
 	gcalconduit_new_context(&ctxt,cfg);
 	gtk_object_set_data(GTK_OBJECT(retval),"gcalconduit_context",ctxt);
@@ -1427,12 +1439,10 @@ conduit_get_gpilot_conduit (guint32 pilotId)
 	gtk_signal_connect (retval, "archive_local", (GtkSignalFunc) archive_local, ctxt);
 	gtk_signal_connect (retval, "archive_remote", (GtkSignalFunc) archive_remote, ctxt);
 	gtk_signal_connect (retval, "store_remote", (GtkSignalFunc) store_remote, ctxt);
-	gtk_signal_connect (retval, "clear_status_archive_local", (GtkSignalFunc) clear_status_archive_local, ctxt);
 	gtk_signal_connect (retval, "iterate", (GtkSignalFunc) iterate, ctxt);
 	gtk_signal_connect (retval, "iterate_specific", (GtkSignalFunc) iterate_specific, ctxt);
 	gtk_signal_connect (retval, "purge", (GtkSignalFunc) purge, ctxt);
 	gtk_signal_connect (retval, "set_status", (GtkSignalFunc) set_status, ctxt);
-	gtk_signal_connect (retval, "set_archived", (GtkSignalFunc) set_archived, ctxt);
 	gtk_signal_connect (retval, "set_pilot_id", (GtkSignalFunc) set_pilot_id, ctxt);
 	gtk_signal_connect (retval, "compare", (GtkSignalFunc) compare, ctxt);
 	gtk_signal_connect (retval, "compare_backup", (GtkSignalFunc) compare_backup, ctxt);
@@ -1465,3 +1475,30 @@ conduit_destroy_gpilot_conduit (GnomePilotConduit *conduit)
 }
 
 
+#ifndef __GNUC__
+static void LOG(gchar *mesg, ...)
+{
+#ifdef DEBUG_CONDUIT
+	va_list ap;
+	va_start(ap, mesg);
+	g_logv(G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE, mesg, ap);
+	va_end(ap);
+#endif /* DEBUG_CONDUIT */
+}
+
+static void WARN(gchar *mesg, ...)
+{
+	va_list ap;
+	va_start(ap, mesg);
+	g_logv(G_LOG_DOMAIN, G_LOG_LEVEL_WARNING, mesg, ap);
+	va_end(ap);
+}
+
+static void INFO(gchar *mesg, ...)
+{
+	va_list ap;
+	va_start(ap, mesg);
+	g_logv(G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE, mesg, ap);
+	va_end(ap);
+}
+#endif /* __GNUC__ */
