@@ -90,7 +90,7 @@ enum RecurType {
 	RECUR_MONTHLY_BY_POS,
 	RECUR_MONTHLY_BY_DAY,
 	RECUR_YEARLY_BY_MONTH,
-	RECUR_YEARLY_BY_DAY,
+	RECUR_YEARLY_BY_DAY
 };
 
 #define DAY_LASTDAY 10000
@@ -182,6 +182,7 @@ typedef struct {
 	/* Pilot */
 	iCalPilotState pilot_status;    /* Status information */
 	guint32            pilot_id;        /* Pilot ID */
+	gboolean           allday;
 } iCalObject;
 
 /* The callback for the recurrence generator */
