@@ -86,6 +86,12 @@ make_spin_button (int val, int low, int high)
 static void
 ee_check_all_day (EventEditor *ee)
 {
+	if (ee->ical->allday) {
+		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (ee->general_allday), 1);
+	} else {
+		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (ee->general_allday), 0);
+	}
+/*
 	time_t ev_start, ev_end;
 
 	ev_start = gnome_date_edit_get_date (GNOME_DATE_EDIT (ee->start_time));
@@ -95,6 +101,7 @@ ee_check_all_day (EventEditor *ee)
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (ee->general_allday), 1);
 	else
 		gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (ee->general_allday), 0);
+*/
 }
 
 /*
@@ -179,7 +186,6 @@ check_times (GnomeDateEdit *gde, EventEditor *ee)
 	}
 
 	/* Check whether the event spans the whole day */
-
 	ee_check_all_day (ee);
 }
 
@@ -192,6 +198,8 @@ set_all_day (GtkToggleButton *toggle, EventEditor *ee)
 	struct tm tm;
 	time_t start_t;
 
+	ee->ical->allday = FALSE;
+	
 	if (toggle->active) {
 		start_t = gnome_date_edit_get_date (GNOME_DATE_EDIT (ee->start_time));
 		tm = *localtime (&start_t);
@@ -201,7 +209,9 @@ set_all_day (GtkToggleButton *toggle, EventEditor *ee)
 		gnome_date_edit_set_time (GNOME_DATE_EDIT (ee->start_time), mktime (&tm));
 		tm.tm_hour = day_end;
 		gnome_date_edit_set_time (GNOME_DATE_EDIT (ee->end_time), mktime (&tm));
+		ee->ical->allday = TRUE;
 	}
+	ee_check_all_day (ee);
 }
 
 /* Convenience function to create a properly-configured date editor widget */
@@ -349,7 +359,14 @@ ee_create_ae (GtkTable *table, char *str, CalendarAlarm *alarm, enum AlarmType t
 	/* is there a "changed" signal which we can connect to? */
 	gtk_option_menu_set_history (GTK_OPTION_MENU (alarm->w_timesel), alarm->units);
 	gtk_table_attach (table, alarm->w_timesel, 2, 3, y, y+1, FS, FS, 0, 0);
-	
+
+	if (dirty_func) {
+		gtk_signal_connect (GTK_OBJECT (gtk_option_menu_get_menu(alarm->w_timesel)), 
+				    "selection-done", 
+				    GTK_SIGNAL_FUNC (dirty_func), 
+				    NULL);
+	}
+
 	switch (type){
 	case ALARM_MAIL:
 		alarm->w_label = gtk_label_new (_("Mail to:"));
