@@ -6,9 +6,13 @@
  *          Miguel de Icaza <miguel@kernel.org>
  */
 #include <config.h>
+
 #include <string.h>
+
+#include <glib.h>
 #include <gdk/gdkkeysyms.h>
 #include <gnome.h>
+
 #include "eventedit.h"
 #include "gncal-full-day.h"
 #include "view-utils.h"
@@ -17,6 +21,7 @@
 #include "popup-menu.h"
 
 /* Images */
+#include "allday.xpm"
 #include "bell.xpm"
 #include "recur.xpm"
 
@@ -109,61 +114,82 @@ static void gncal_full_day_forall         (GtkContainer      *container,
 					   gpointer           callback_data);
 
 static void range_activated (GncalFullDay *fullday);
+static gint update_calendar_object (Child* child);
 
 static GtkContainerClass *parent_class;
 
-static int fullday_signals[LAST_SIGNAL] = { 0 };
+static guint fullday_signals[LAST_SIGNAL] = { 0 };
 
 /* The little images */
-static GdkPixmap *pixmap_bell, *pixmap_recur;
+static GdkPixmap *pixmap_bell, *pixmap_recur, *pixmap_allday;
 
+/* This function computes, which rows are used for a time interval given
+ * by "time_lower" and "time_upper". The first row is 0:00 of each day and
+ * each row signifies "interval" minutes. The first row used is returned
+ * in "lower_row" (if not NULL) and the number of rows used is returned
+ * in "rows_used" (if not NULL).
+ *
+ * The variables "lower" and "upper" (if not NULL) will contain the start
+ * and end time of the selected rows, respectively.
+ */
 static void
-get_tm_range (GncalFullDay *fullday,
-	      time_t time_lower, time_t time_upper,
-	      struct tm *lower, struct tm *upper,
-	      int *lower_row, int *rows_used)
+time_row_usage (int interval,
+		time_t time_lower, time_t time_upper,
+		struct tm *lower, struct tm *upper,
+		int *lower_row, int *rows_used)
 {
 	struct tm tm_lower, tm_upper;
 	int lmin, umin;
-	int lrow;
+	int lrow, rows;
 
-	/* Lower */
+	g_return_if_fail (interval > 0);
+	g_return_if_fail (time_lower <= time_upper);
+
+	/* Computer Lower Boundary */
 
 	tm_lower = *localtime (&time_lower);
 
-	if ((tm_lower.tm_min % fullday->interval) != 0) {
-		tm_lower.tm_min -= tm_lower.tm_min % fullday->interval; /* round down */
-		mktime (&tm_lower);
-	}
+	tm_lower.tm_min %= interval; /* round down */
 
-	/* Upper */
+	mktime (&tm_lower);
+
+	/* Compute Upper Boundary */
 
 	tm_upper = *localtime (&time_upper);
 
-	if ((tm_upper.tm_min % fullday->interval) != 0) {
-		tm_upper.tm_min += fullday->interval - (tm_upper.tm_min % fullday->interval); /* round up */
-		mktime (&tm_upper);
+	if (tm_upper.tm_min % interval != 0) { /* round up */
+		tm_upper.tm_min %= interval;
+		tm_upper.tm_min += interval;
 	}
 
+	mktime (&tm_upper);
+
+	/* Store Boundaries */
+
 	if (lower)
 		*lower = tm_lower;
 
 	if (upper)
 		*upper = tm_upper;
 
+	/* Compute the Interval's Lower Row and Row Count */
+
 	lmin = 60 * tm_lower.tm_hour + tm_lower.tm_min;
 	umin = 60 * tm_upper.tm_hour + tm_upper.tm_min;
 
 	if (umin == 0) /* midnight of next day? */
 		umin = 60 * 24;
 
-	lrow = lmin / fullday->interval;
+	lrow = lmin / interval;
+	rows = umin / interval - lrow;
+
+	/* Store Row Information */
 
 	if (lower_row)
 		*lower_row = lrow;
 
 	if (rows_used)
-		*rows_used = (umin - lmin) / fullday->interval;
+		*rows_used = rows;
 }
 
 static void
@@ -250,7 +276,7 @@ child_realize (GncalFullDay *fullday, Child *child)
 	gdk_window_set_user_data (child->decor_window, widget);
 
 	if (!pixmap_bell){
-		GdkImlibImage *imlib_bell, *imlib_recur;
+		GdkImlibImage *imlib_bell, *imlib_recur, *imlib_allday;
 		GdkPixmap *mask;
 		
 		imlib_bell  = gdk_imlib_create_image_from_xpm_data (bell_xpm);
@@ -270,6 +296,15 @@ child_realize (GncalFullDay *fullday, Child *child)
 		fullday->recur_gc = gdk_gc_new (child->decor_window);
 		if (mask)
 			gdk_gc_set_clip_mask (fullday->recur_gc, mask);
+
+		imlib_allday = gdk_imlib_create_image_from_xpm_data (allday_xpm);
+		gdk_imlib_render (imlib_allday, DECOR_WIDTH, DECOR_HEIGHT);
+		pixmap_allday = gdk_imlib_move_image (imlib_allday);
+		mask = gdk_imlib_move_mask (imlib_allday);
+		gdk_imlib_destroy_image (imlib_allday);
+		fullday->allday_gc = gdk_gc_new (child->decor_window);
+		if (mask)
+			gdk_gc_set_clip_mask (fullday->allday_gc, mask);
 	}
 	child_set_text_pos (child);
 }
@@ -290,7 +325,7 @@ child_draw_decor (GncalFullDay *fullday, Child *child)
 {
 	iCalObject *ico = child->ico;
 	int ry = 0;
-
+	
 	if (ico->recur) {
 		gdk_gc_set_clip_origin (fullday->recur_gc, 0, ry);
 		gdk_draw_pixmap (child->decor_window,
@@ -302,6 +337,17 @@ child_draw_decor (GncalFullDay *fullday, Child *child)
 		ry += DECOR_HEIGHT;
 	}
 
+	if (ico->allday) {
+		gdk_gc_set_clip_origin (fullday->allday_gc, 0, ry);
+		gdk_draw_pixmap (child->decor_window,
+				 fullday->allday_gc,
+				 pixmap_allday,
+				 0, 0,
+				 0, ry,
+				 DECOR_WIDTH, DECOR_HEIGHT);
+		ry += DECOR_HEIGHT;
+	}
+
 	if (ico->dalarm.enabled || ico->malarm.enabled || ico->palarm.enabled || ico->aalarm.enabled) {
 		gdk_gc_set_clip_origin (fullday->bell_gc, 0, ry);
 		gdk_draw_pixmap (child->decor_window,
@@ -389,8 +435,8 @@ child_range_changed (GncalFullDay *fullday, Child *child)
 
 	/* Calc display range for event */
 
-	get_tm_range (fullday, child->start, child->end, &start, &end, &lower_row, &rows_used);
-	get_tm_range (fullday, fullday->lower, fullday->upper, NULL, NULL, &f_lower_row, NULL);
+	time_row_usage (fullday->interval, child->start, child->end, &start, &end, &lower_row, &rows_used);
+	time_row_usage (fullday->interval, fullday->lower, fullday->upper, NULL, NULL, &f_lower_row, NULL);
 
 	child->lower_row = lower_row - f_lower_row;
 	child->rows_used = rows_used;
@@ -421,6 +467,7 @@ edit_appointment (GtkWidget *widget, gpointer data)
 
 	child = data;
 
+	update_calendar_object (child);
 	ee = event_editor_new (GNCAL_FULL_DAY (child->widget->parent)->calendar, child->ico);
 	gtk_widget_show (ee);
 }
@@ -569,7 +616,7 @@ calc_row_height (GncalFullDay *fullday)
 	int f_rows;
 	GtkWidget *widget;
 
-	get_tm_range (fullday, fullday->lower, fullday->upper, NULL, NULL, NULL, &f_rows);
+	time_row_usage (fullday->interval, fullday->lower, fullday->upper, NULL, NULL, NULL, &f_rows);
 
 	widget = GTK_WIDGET (fullday);
 
@@ -608,21 +655,18 @@ child_focus_in (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 }
 
 static gint
-child_focus_out (GtkWidget *widget, GdkEventFocus *event, gpointer data)
+update_calendar_object (Child* child)
 {
-	Child *child;
 	GncalFullDay *fullday;
 	char *text;
 
-	child = data;
-
-	child_set_size (child);
-
 	/* Update summary in calendar object */
 
-	text = gtk_editable_get_chars (GTK_EDITABLE (widget), 0, -1);
-	if (child->ico->summary && strcmp (text, child->ico->summary) == 0)
+	text = gtk_editable_get_chars (GTK_EDITABLE (child->widget), 0, -1);
+	if (child->ico->summary && strcmp (text, child->ico->summary) == 0) {
+		g_free (text);
 		return FALSE;
+	}
 
 	if (child->ico->summary)
 		g_free (child->ico->summary);
@@ -631,7 +675,7 @@ child_focus_out (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 
 	/* Notify calendar of change */
 
-	fullday = GNCAL_FULL_DAY (widget->parent);
+	fullday = GNCAL_FULL_DAY (child->widget->parent);
 
 	gnome_calendar_object_changed (fullday->calendar, child->ico, CHANGE_SUMMARY);
 	save_default_calendar (fullday->calendar);
@@ -639,6 +683,18 @@ child_focus_out (GtkWidget *widget, GdkEventFocus *event, gpointer data)
 	return FALSE;
 }
 
+static gint
+child_focus_out (GtkWidget *widget, GdkEventFocus *event, gpointer data)
+{
+	Child *child;
+
+	child = data;
+
+	child_set_size (child);
+	
+	return update_calendar_object (child);
+}
+
 static gint
 child_key_press (GtkWidget *widget, GdkEventKey *event, gpointer data)
 {
@@ -683,6 +739,8 @@ child_compute_decor (Child *child)
 
 	child->items = 0;
 	rows_used = (child->rows_used < 1) ? 1 : child->rows_used;
+	if (ico->allday)
+		child->items++;
 	if (ico->recur)
 		child->items++;
 	if (ico->dalarm.enabled || ico->aalarm.enabled || ico->palarm.enabled || ico->malarm.enabled)
@@ -790,7 +848,7 @@ calc_labels_width (GncalFullDay *fullday)
 	int width, max_w;
 	char buf[40];
 
-	get_tm_range (fullday, fullday->lower, fullday->upper, &cur, &upper, NULL, NULL);
+	time_row_usage (fullday->interval, fullday->lower, fullday->upper, &cur, &upper, NULL, NULL);
 
 	max_w = 0;
 
@@ -888,8 +946,8 @@ gncal_full_day_get_type (void)
 			sizeof (GncalFullDayClass),
 			(GtkClassInitFunc) gncal_full_day_class_init,
 			(GtkObjectInitFunc) gncal_full_day_init,
-			(GtkArgSetFunc) NULL,
-			(GtkArgGetFunc) NULL
+			NULL,
+			NULL
 		};
 
 		full_day_type = gtk_type_unique (gtk_container_get_type (), &full_day_info);
@@ -961,6 +1019,7 @@ gncal_full_day_init (GncalFullDay *fullday)
 
 	fullday->up_down_cursor = NULL;
 	fullday->beam_cursor = NULL;
+	fullday->allday_gc = NULL;
 	fullday->recur_gc = NULL;
 	fullday->bell_gc = NULL;
 }
@@ -1116,11 +1175,20 @@ gncal_full_day_unrealize (GtkWidget *widget)
 	gdk_cursor_destroy (fullday->beam_cursor);
 	fullday->beam_cursor = NULL;
 
+	if (fullday->allday_gc)
+		gdk_gc_destroy (fullday->allday_gc);
+
 	if (fullday->bell_gc)
 		gdk_gc_destroy (fullday->bell_gc);
+
 	if (fullday->recur_gc)
 		gdk_gc_destroy (fullday->recur_gc);
 
+	if (pixmap_allday){
+		gdk_pixmap_unref (pixmap_allday);
+		pixmap_allday = NULL;
+	}
+
 	if (pixmap_bell){
 		gdk_pixmap_unref (pixmap_bell);
 		pixmap_bell = NULL;
@@ -1262,7 +1330,7 @@ paint_back (GncalFullDay *fullday, GdkRectangle *area)
 
 	p.labels_width = calc_labels_width (fullday);
 	p.row_height = calc_row_height (fullday);
-	get_tm_range (fullday, fullday->lower, fullday->upper, &p.start_tm, NULL, NULL, &f_rows);
+	time_row_usage (fullday->interval, fullday->lower, fullday->upper, &p.start_tm, NULL, NULL, &f_rows);
 
 	/* Frame shadow */
 
@@ -1438,7 +1506,7 @@ gncal_full_day_size_request (GtkWidget *widget, GtkRequisition *requisition)
 
 	/* Rows */
 
-	get_tm_range (fullday, fullday->lower, fullday->upper, NULL, NULL, NULL, &rows);
+	time_row_usage (fullday->interval, fullday->lower, fullday->upper, NULL, NULL, NULL, &rows);
 
 	requisition->height += (rows * (2 * TEXT_BORDER + widget->style->font->ascent + widget->style->font->descent)
 				+ (rows - 1)); /* division lines */
@@ -1532,7 +1600,7 @@ get_row_from_y (GncalFullDay *fullday, int y, int round)
 	int f_rows;
 	int ythickness;
 
-	get_tm_range (fullday, fullday->lower, fullday->upper, NULL, NULL, NULL, &f_rows);
+	time_row_usage (fullday->interval, fullday->lower, fullday->upper, NULL, NULL, NULL, &f_rows);
 
 	row_height = calc_row_height (fullday);
 
@@ -1738,7 +1806,7 @@ recompute_motion (GncalFullDay *fullday, int y)
 
 	di = fullday->drag_info;
 
-	get_tm_range (fullday, fullday->lower, fullday->upper, NULL, NULL, NULL, &f_rows);
+	time_row_usage (fullday->interval, fullday->lower, fullday->upper, NULL, NULL, NULL, &f_rows);
 
 	switch (di->drag_mode) {
 	case DRAG_SELECT:
@@ -1816,7 +1884,7 @@ get_time_from_rows (GncalFullDay *fullday, int start_row, int rows_used, time_t
 	struct tm tm;
 	int row_height;
 
-	get_tm_range (fullday, fullday->lower, fullday->upper, &tm, NULL, NULL, NULL);
+	time_row_usage (fullday->interval, fullday->lower, fullday->upper, &tm, NULL, NULL, NULL);
 
 	row_height = calc_row_height (fullday);
 
@@ -2261,6 +2329,7 @@ gncal_full_day_get_day_start_yoffset (GncalFullDay *fullday)
 
 	g_return_val_if_fail (fullday != NULL, 0);
 	g_return_val_if_fail (GNCAL_IS_FULL_DAY (fullday), 0);
+	g_return_val_if_fail (fullday->interval > 0, 0);
 
 	widget = GTK_WIDGET (fullday);
 
