@@ -444,7 +444,13 @@ init_column_sorting (GtkCList *clist)
 	
 	clist->sort_type = todo_current_sort_type;
 	clist->sort_column = todo_current_sort_column;
-	
+
+	if (todo_current_sort_column == 1 /* due date */ ||
+	    todo_current_sort_column == 3 /* time left */)
+		gtk_clist_set_compare_func (clist, gncal_todo_compare_date_func);
+	else
+		gtk_clist_set_compare_func (clist, NULL);
+
 	gtk_clist_set_sort_column (clist, todo_current_sort_column);
 	gtk_clist_sort (clist);
 }
@@ -481,7 +487,8 @@ todo_click_column (GtkCList *clist, gint column, gpointer data)
 		todo_current_sort_column = column;
 	}
 	
-	if (column == 1)
+	if (column == 1 /* due date */ ||
+	    column == 3 /* time left */)
 		gtk_clist_set_compare_func (clist, gncal_todo_compare_date_func);
 	else
 		gtk_clist_set_compare_func (clist, NULL);
@@ -514,13 +521,13 @@ gncal_todo_init (GncalTodo *todo)
 	GtkWidget *w;
 	GtkWidget *sw;
 	GtkWidget *hbox;
-	gchar *titles[5] = {
-		_("Summary"),
-		_("Due Date"),
-		_("Priority"),
-		_("Time Left"),
-		_("Categories")
-	};
+	gchar *titles[5];
+
+	titles[0] = _("Summary");
+	titles[1] = _("Due Date");
+	titles[2] = _("Priority");
+	titles[3] = _("Time Left");
+	titles[4] = _("Categories");
 
 	gtk_box_set_spacing (GTK_BOX (todo), 5);
 
@@ -622,7 +629,7 @@ convert_time_t_to_char (time_t t)
 	struct tm tm;
 
 	tm = *localtime (&t);
-	strftime(buf, sizeof (buf), "%m/%d/%Y", &tm);
+	strftime(buf, sizeof (buf), "%x", &tm);
 
 	return g_strdup (buf);
 }
@@ -659,6 +666,7 @@ make_todo_style(GncalTodo *todo, todo_status style_type)
 	  color_prop = COLOR_PROP_TODO_OVERDUE;
 	  break;
 	case TODO_ITEM_DSTATUS_LAST_DUE_STATUS:
+	  break;
 	}
 	
 	style_color.red   = color_props[color_prop].r;
@@ -894,6 +902,7 @@ insert_in_clist (GncalTodo *todo, iCalObject *ico)
 	    }
 	  break;
 	case TODO_ITEM_DSTATUS_LAST_DUE_STATUS:
+	  break;
 	}
 	
 	/* keep the list in order */
