@@ -58,11 +58,7 @@ jump_to_day (GtkCalendar *cal, GncalWeekView *wview, int day)
 {
 	struct tm tm;
 	time_t t;
-	static int inside;
 	
-	if (inside)
-		return;
-	inside = 1;
 	tm.tm_mday = day;
 	tm.tm_mon  = cal->month;
 	tm.tm_year = cal->year - 1900;
@@ -72,8 +68,7 @@ jump_to_day (GtkCalendar *cal, GncalWeekView *wview, int day)
 	tm.tm_isdst = -1;
 	t = mktime (&tm);
 
-	gncal_week_view_set (wview, t);
-	inside = 0;
+	gnome_calendar_goto (wview->calendar, t);
 }
 
 static void
@@ -85,7 +80,17 @@ jump_to_day_click (GtkCalendar *cal, GncalWeekView *wview)
 static void
 sync_week (GtkCalendar *cal, GncalWeekView *wview)
 {
-	jump_to_day (cal, wview, wview->start_of_week.tm_mday + 7);
+	gint day;
+
+	day = wview->start_of_week.tm_mday;
+	if (wview->start_of_week.tm_mday < 7) {
+		day += 7;
+	} else if (wview->start_of_week.tm_mday > 28) {
+		day = 28;
+	}
+
+	jump_to_day (cal, wview, day);
+
 	gnome_calendar_tag_calendar (wview->calendar, wview->gtk_calendar);
 }
 
@@ -144,6 +149,7 @@ gncal_week_view_new (GnomeCalendar *calendar, time_t start_of_week)
 	gtk_calendar_display_options (wview->gtk_calendar,
 				      (GTK_CALENDAR_SHOW_HEADING
 				       | GTK_CALENDAR_SHOW_DAY_NAMES
+				       | GTK_CALENDAR_SHOW_WEEK_NUMBERS
 				       | (week_starts_on_monday
 					  ? GTK_CALENDAR_WEEK_START_MONDAY : 0)));
 
@@ -184,8 +190,8 @@ gncal_week_view_update (GncalWeekView *wview, iCalObject *ico, int flags)
 void
 gncal_week_view_set (GncalWeekView *wview, time_t start_of_week)
 {
-	struct tm tm;
-	time_t day_start, day_end, week_start, week_end;
+	struct tm tm, tm_curr;
+	time_t day_start, day_end, week_start, week_end, day_curr;
 	int i;
 
 	g_return_if_fail (wview != NULL);
@@ -193,9 +199,13 @@ gncal_week_view_set (GncalWeekView *wview, time_t start_of_week)
 
 	tm = *localtime (&start_of_week);
 	
-	/* back up to start of week (Monday) */
+	/* back up to start of week */
 
-	tm.tm_mday -= (tm.tm_wday == 0) ? 6 : (tm.tm_wday - 1);
+	if (week_starts_on_monday) {
+	    tm.tm_mday -= (tm.tm_wday == 0) ? 6 : (tm.tm_wday - 1);
+	} else {
+		tm.tm_mday -= tm.tm_wday;
+	}
 	
 	/* Start of day */
 
@@ -204,10 +214,23 @@ gncal_week_view_set (GncalWeekView *wview, time_t start_of_week)
 	tm.tm_sec  = 0;
 
 	day_start = week_start = mktime (&tm);
-	
+
+	wview->start_of_week = tm;
+
 	/* Calendar */
 
-	gtk_calendar_select_month (wview->gtk_calendar, tm.tm_mon, tm.tm_year + 1900);
+	if (tm.tm_mon != wview->gtk_calendar->month)
+		gtk_calendar_select_month (wview->gtk_calendar,
+					   tm.tm_mon, tm.tm_year + 1900);
+
+	day_curr = time (NULL);
+	tm_curr = *localtime (&day_curr);
+	if (wview->gtk_calendar->year - 1900 == tm_curr.tm_year &&
+	    wview->gtk_calendar->month       == tm_curr.tm_mon) {
+		gtk_calendar_select_day (wview->gtk_calendar, tm_curr.tm_mday);
+	} else {
+		gtk_calendar_select_day (wview->gtk_calendar, 0);
+	}
 
 	/* Day views */
 
@@ -231,7 +254,7 @@ gncal_week_view_set (GncalWeekView *wview, time_t start_of_week)
 		strftime (buf[0], sizeof (buf[0]), _("%a %b %d %Y"), 
 			localtime(&week_start));
 
-		strftime (buf[1], sizeof (buf[1]), _("%a %b %d %Y"),
+		strftime (buf[1], sizeof (buf[1]), _("%a %b %d %Y (Week %V)"),
 			localtime(&week_end));
 
 		g_snprintf(buf[2], sizeof(buf[2]), "%s - %s", buf[0], buf[1]);
