@@ -549,7 +549,7 @@ mark_gtk_calendar_day (iCalObject *obj, time_t start, time_t end, void *c)
 	tm_s = *localtime (&start);
 	day_end = time_day_end (end);
 
-	for (t = start; t <= day_end; t += 60*60*24){
+	for (t = start; t < day_end; t += 60*60*24){
 		time_t new = mktime (&tm_s);
 		struct tm tm_day;
 
