@@ -53,7 +53,7 @@ int startup_hidden = 0;
 int debug_alarms = 0;
 
 /* If true, move calendar to new day at midnight */
-int roll_at_midnight = 0;
+gboolean roll_at_midnight = FALSE;
 
 /* The array of color properties -- keep in sync with the enumeration defined in main.h.  The color
  * values specified here are the defaults for the program.
@@ -66,6 +66,7 @@ struct color_prop color_props[] = {
 	{ 0xd364, 0xc6b7, 0x7969, N_("Highlighted day:"),      "/calendar/Colors/prelight_bg" },
 	{ 0x01f0, 0x01f0, 0x01f0, N_("Day numbers:"),          "/calendar/Colors/day_fg" },
 	{ 0x0000, 0x0000, 0xffff, N_("Current day's number:"), "/calendar/Colors/current_fg" },
+	{ 0xdd16, 0x3a86, 0x3a86, N_("Event day's number:"), "/calendar/Colors/event_fg" },
 	{ 0xbbbb, 0xbbbb, 0x0000, N_("To-Do item that is not yet due:"), "/calendar/Colors/todo_not_yet" },
 	{ 0xdddd, 0xbbbb, 0x0000, N_("To-Do item that is due today:"),   "/calendar/Colors/todo_today" },
 	{ 0xbbbb, 0xdddd, 0x0000, N_("To-Do item that is overdue:"),     "/calendar/Colors/todo_overdue" }
@@ -592,14 +593,6 @@ save_default_calendar (GnomeCalendar *gcal)
 	save_calendar_cmd (NULL, gcal);
 }
 
-#if 0
-static void
-make_html_cmd (GtkWidget *widget, GtkWidget *gcal)
-{
-	make_month_html (gcal, "output.html");
-}
-#endif
-
 static GnomeUIInfo gnome_cal_file_menu [] = {
         GNOMEUIINFO_MENU_NEW_ITEM(N_("_New calendar"),
 				  N_("Create a new calendar"),
@@ -613,13 +606,6 @@ static GnomeUIInfo gnome_cal_file_menu [] = {
 
 	GNOMEUIINFO_SEPARATOR,
 
-#if 0
-	GNOMEUIINFO_ITEM(N_("Create HTML for this month"),
-			 N_("Creates an HTML version of this month's appointments"),
-			 make_html_cmd, NULL);
-#endif
-	GNOMEUIINFO_SEPARATOR,
-
 	GNOMEUIINFO_MENU_CLOSE_ITEM(close_cmd, NULL),
 
 	GNOMEUIINFO_MENU_EXIT_ITEM(quit_cmd, NULL),
@@ -704,27 +690,17 @@ GnomeCalendar *
 new_calendar (char *full_name, char *calendar_file, char *geometry, char *page, gboolean hidden)
 {
 	GtkWidget   *toplevel;
-	char        title[128];
+	gchar       *title;
 	int         xpos, ypos, width, height;
 
-	/* i18n: This "%s%s" indicates possession. Languages where the order is
-	 * the inverse should translate it to "%2$s%1$s".
-	 */
-	g_snprintf(title, 128, _("%s%s"), full_name, _("'s calendar"));
-
+	title = g_strdup_printf(_("%s's calendar"), full_name);
 	toplevel = gnome_calendar_new (title);
+	g_free (title);
 	
 	if (gnome_parse_geometry (geometry, &xpos, &ypos, &width, &height)){
 		if (xpos != -1)
 			gtk_widget_set_uposition (toplevel, xpos, ypos);
-#if 0
-	if (width != -1)
-		gtk_widget_set_usize (toplevel, width, 600);
-#endif
 	}
-#if 0
- 	gtk_widget_set_usize (toplevel, width, 600); 
-#endif
 
 	setup_appbar (toplevel);
 	setup_menu (toplevel);
@@ -897,16 +873,15 @@ parse_an_arg (poptContext ctx,
 		 */
 		arg = COOKIE_USER_HOME_DIR;
 		/* fall through */
-		break;
-		
-	case VIEW_KEY:
-		start_views = g_list_append (start_views, arg);
-		break;
 
 	case 'F':
 		start_calendars = g_list_append (start_calendars, arg);
 		break;
 
+	case VIEW_KEY:
+		start_views = g_list_append (start_views, arg);
+		break;
+
 	case TODO_KEY:
 		show_todo = 1;
 		break;
@@ -925,6 +900,7 @@ parse_an_arg (poptContext ctx,
 		break;
 		
 	default:
+		break;
 	}
 }
 
