@@ -1,12 +1,19 @@
 #ifndef MAIN_H
 #define MAIN_H
 
+#include <glib.h>
+#include <gtk/gtkwidget.h>
+
+#include "calobj.h"
+#include "gnome-cal.h"
+
 /* Calendar preferences */
 
 extern int day_begin, day_end;
 extern char *user_name;
 extern int am_pm_flag;
 extern int week_starts_on_monday;
+extern gboolean roll_at_midnight;
 
 
 /* This enum and the following array define the color preferences */
@@ -19,6 +26,7 @@ typedef enum {
 	COLOR_PROP_PRELIGHT_DAY_BG,	/* Background color for prelighted day */
 	COLOR_PROP_DAY_FG,		/* Color for day numbers */
 	COLOR_PROP_CURRENT_DAY_FG,	/* Color for current day's number */
+	COLOR_PROP_EVENT_DAY_FG,	/* Color for current day's number */
 	COLOR_PROP_TODO_NOT_DUE_YET,    /* Color for Todo items not yet due */
 	COLOR_PROP_TODO_DUE_TODAY,      /* Color for Todo items due today */ 
 	COLOR_PROP_TODO_OVERDUE,        /* Color for Todo items that are overdue */
@@ -61,6 +69,9 @@ extern gboolean enable_snooze;
 extern guint snooze_secs;
 extern const guint MAX_SNOOZE_SECS;
 
+/* List of all calendars */
+extern GList *all_calendars;
+
 /* Creates and runs the preferences dialog box */
 void properties (GtkWidget *toplevel);
 
