@@ -40,7 +40,8 @@ void colorify_month_item (GnomeMonthItem *month, GetColorFunc func, gpointer fun
 void mark_month_item (GnomeMonthItem *mitem, Calendar *cal);
 
 /* Marks a day specified by index, not by day number */
-void mark_month_item_index (GnomeMonthItem *mitem, int index, GetColorFunc func, gpointer func_data);
+void mark_month_item_index (GnomeMonthItem *mitem, int index, CalendarObject *obj, 
+			    GetColorFunc func, gpointer func_data);
 
 /* Unmarks all the days in the specified month item */
 void unmark_month_item (GnomeMonthItem *mitem);
