@@ -80,7 +80,7 @@ do_quick_view_popup (MonthView *mv, GdkEventButton *event, int day)
 	GtkWidget *qv;
 	char date_str[256];
 
-	day_begin_time = time_from_day (mv->year, mv->month, day);
+	day_begin_time = time_day_begin (time_from_day (mv->year, mv->month, day));
 	day_end_time = time_day_end (day_begin_time);
 
 	list = calendar_get_events_in_range (mv->calendar->cal, day_begin_time, day_end_time);
@@ -639,7 +639,32 @@ add_event (iCalObject *ico, time_t start, time_t end, void *data)
 
 	do {
 		tm = *localtime (&day_begin_time);
-		g_string_sprintfa (ii->strings[ii->first_day_index + tm.tm_mday - 1], "%s\n", ico->summary);
+
+		if (!ico->allday) {
+			char *buf;
+			char start[100];
+			struct tm start_tm;
+
+			/* construct struct tm objects for the begin/end */
+			start_tm = *localtime (&ico->dtstart);
+
+			/* generate weird 12hour format */
+			if (am_pm_flag) {
+				strftime (start, sizeof (start), "%I:%M%p", &start_tm);
+			} else {
+				strftime (start, sizeof (start), "%H:%M", &start_tm);
+			}
+
+			buf = g_strdup_printf ("%s: %s\n",
+					       start,
+					       ico->summary);
+			g_string_sprintfa (ii->strings[ii->first_day_index + tm.tm_mday - 1], 
+					   "%s\n", buf);
+			g_free (buf);
+		} else {
+			g_string_sprintfa (ii->strings[ii->first_day_index + tm.tm_mday - 1], 
+					   "%s\n", ico->summary);
+		}
 
 		/* Next day */
 
@@ -650,11 +675,17 @@ add_event (iCalObject *ico, time_t start, time_t end, void *data)
 	return TRUE; /* this means we are not finished yet with event generation */
 }
 
+static void do_add (gpointer data, gpointer user_data) {
+	CalendarObject *co = data;
+	add_event (co->ico, co->ev_start, co->ev_end, user_data);
+}
+
 void
 month_view_update (MonthView *mv, iCalObject *object, int flags)
 {
 	struct iter_info ii;
 	GString *strings[42];
+	GList   *events;
 	int i;
 	time_t t;
 
@@ -679,7 +710,9 @@ month_view_update (MonthView *mv, iCalObject *object, int flags)
 	ii.month_begin = time_month_begin (t);
 	ii.month_end = time_month_end (t);
 
-	calendar_iterate (mv->calendar->cal, ii.month_begin, ii.month_end, add_event, &ii);
+	events = calendar_get_events_in_range (mv->calendar->cal, ii.month_begin, ii.month_end);
+	g_list_foreach (events, do_add, &ii);
+	calendar_destroy_event_list (events);
 
 	for (i = 0; i < 42; i++) {
 		/* Delete the last character if it is a newline */
