@@ -37,6 +37,7 @@ static GtkWidget *start_omenu;		/* Option menu for start of day */
 static GtkWidget *end_omenu;		/* Option menu for end of day */
 static GtkWidget *start_items[24];	/* Menu items for start of day menu */
 static GtkWidget *end_items[24];	/* Menu items for end of day menu */
+static GtkWidget *roll_date_on_midnight;/* Checkbox for date change on midnight */
 
 /* Widgets for the colors page */
 
@@ -79,6 +80,7 @@ static int
 prop_cancel (void)
 {
 	prop_win = NULL;
+
 	return FALSE;
 }
 
@@ -89,6 +91,7 @@ get_active_index (GtkWidget *menu)
 	GtkWidget *active;
 
 	active = gtk_menu_get_active (GTK_MENU (menu));
+
 	return GPOINTER_TO_INT (gtk_object_get_user_data (GTK_OBJECT (active)));
 }
 
@@ -105,14 +108,20 @@ prop_apply_time_display (void)
 
 	/* Time format */
 
-	am_pm_flag = GTK_TOGGLE_BUTTON (time_format_12)->active;
+	am_pm_flag = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (time_format_12));
 	gnome_config_set_bool ("/calendar/Calendar/AM PM flag", am_pm_flag);
 
 	/* Week start */
 
-	week_starts_on_monday = GTK_TOGGLE_BUTTON (start_on_monday)->active;
+	week_starts_on_monday = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (start_on_monday));
 	gnome_config_set_bool ("/calendar/Calendar/Week starts on Monday", week_starts_on_monday);
 
+	/* Roll over */
+
+	roll_at_midnight = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (roll_date_on_midnight));
+	gnome_config_set_bool ("/calendar/Calendar/Display new date at midnight",
+			       roll_at_midnight);
+
 	gnome_config_sync ();
 	time_format_changed ();
 }
@@ -138,9 +147,10 @@ prop_apply_colors (void)
 	gnome_config_sync ();
 	colors_changed ();
 }
+
 /* Applies the settings in the todo page (FIX THIS IF ITS NOT WRITTEN) */
 static void
-prop_apply_todo(void) 
+prop_apply_todo (void) 
 {
 	todo_show_due_date = GTK_TOGGLE_BUTTON (due_date_show_button)->active;
 	
@@ -174,7 +184,7 @@ prop_apply_todo(void)
 
 /* Callback used when the Apply button is clicked. */
 static void
-prop_apply (GtkWidget *w, int page)
+prop_apply (GtkWidget *widget, int page)
 {
 	switch (page) {
 	case PROP_TIME_DISPLAY:
@@ -261,7 +271,8 @@ hour_activated (GtkWidget *widget, gpointer data)
 
 		if (end < start)
 			gtk_option_menu_set_history (GTK_OPTION_MENU (end_omenu), start);
-	} else if (data == end_omenu) {
+	}
+	else if (data == end_omenu) {
 		/* Adjust the start menu */
 
 		end = GPOINTER_TO_INT (gtk_object_get_user_data (GTK_OBJECT (widget)));
@@ -269,7 +280,8 @@ hour_activated (GtkWidget *widget, gpointer data)
 
 		if (start > end)
 			gtk_option_menu_set_history (GTK_OPTION_MENU (start_omenu), end);
-	} else
+	}
+	else
 		g_assert_not_reached ();
 
 	gnome_property_box_changed (GNOME_PROPERTY_BOX (prop_win));
@@ -288,7 +300,7 @@ build_hours_menu (GtkWidget **items, int active)
 
 	omenu = gtk_option_menu_new ();
 	menu = gtk_menu_new ();
-	am_pm_flag = GTK_TOGGLE_BUTTON (time_format_12)->active;
+	am_pm_flag = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (time_format_12));
 
 	memset (&tm, 0, sizeof (tm));
 
@@ -401,6 +413,14 @@ create_time_display_page (void)
 
 	end_omenu = build_hours_menu (end_items, day_end);
 	gtk_box_pack_start (GTK_BOX (hbox3), end_omenu, FALSE, FALSE, 0);
+
+	/* Roll over to next day on Midnight */
+	roll_date_on_midnight = gtk_check_button_new_with_label (_("Roll calendar to next day on midnight"));
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (roll_date_on_midnight),
+				      roll_at_midnight);
+	gtk_signal_connect (GTK_OBJECT (roll_date_on_midnight), "toggled",
+			    (GtkSignalFunc) prop_changed, NULL);
+	gtk_box_pack_start (GTK_BOX (vbox), roll_date_on_midnight, FALSE, FALSE, 5);
 }
 
 /* Called when the canvas for the month item is size allocated.  We use this to change the canvas'
@@ -449,7 +469,7 @@ fake_mark_days (void)
 
 	for (i = 0; i < (sizeof (day_nums) / sizeof (day_nums[0])); i++)
 		mark_month_item_index (GNOME_MONTH_ITEM (month_item), first_day_index + day_nums[i] - 1,
-				       fetch_color_spec, NULL);
+				       NULL, fetch_color_spec, NULL);
 }
 
 /* Switches the month item to the current date and highlights the current day's number */
@@ -578,10 +598,8 @@ create_colors_page (void)
 
 
 static void
-set_todo_page_options(void)
+set_todo_page_options (void)
 {
-  
-  
 	while (gtk_events_pending ())
 		gtk_main_iteration ();
 }
@@ -595,7 +613,7 @@ todo_option_set (void)
 
 /* Creates the colors page in the preferences dialog */
 static GtkWidget *
-build_list_options_frame(void) 
+build_list_options_frame (void) 
 {
 	GtkWidget *frame;
 	GtkWidget *vbox;
@@ -640,8 +658,9 @@ build_list_options_frame(void)
 
 	return frame;
 }
+
 static GtkWidget *
-build_style_list_options_frame(void) 
+build_style_list_options_frame (void) 
 {
 	GtkWidget *frame;
 	GtkWidget *vbox;
@@ -665,10 +684,12 @@ build_style_list_options_frame(void)
 			    "clicked",
 			    (GtkSignalFunc) todo_option_set,
 			    NULL);
+
 	gtk_signal_connect (GTK_OBJECT(todo_item_highlight_not_due_yet),
 			    "clicked",
 			    (GtkSignalFunc) todo_option_set,
 			    NULL);
+
 	gtk_signal_connect (GTK_OBJECT(todo_item_highlight_due_today),
 			    "clicked",
 			    (GtkSignalFunc) todo_option_set,
@@ -677,8 +698,10 @@ build_style_list_options_frame(void)
 	gtk_box_pack_start (GTK_BOX (vbox), todo_item_highlight_overdue, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), todo_item_highlight_due_today, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), todo_item_highlight_not_due_yet, FALSE, FALSE, 0);
+
 	return frame;
 }
+
 static void
 create_todo_page (void)
 {
@@ -686,7 +709,6 @@ create_todo_page (void)
 	GtkWidget *main_box;
 	GtkWidget *hbox;
 
-
 	frame = gtk_frame_new (_("To Do List Properties"));
 	gtk_container_set_border_width (GTK_CONTAINER (frame), GNOME_PAD_SMALL);
 	gnome_property_box_append_page (GNOME_PROPERTY_BOX (prop_win), frame,
@@ -709,14 +731,19 @@ create_todo_page (void)
  	set_todo_page_options(); 
 }
 
+/* Show the help docs for the preferences dialog */
+static void
+prop_help (GtkWidget *widget, gint page_num, gpointer data)
+{
+	GnomeHelpMenuEntry help_entry = { "gnomecal", "calsetup.html" };
+
+	gnome_help_display (widget, &help_entry);
+}
+
 /* Creates and displays the preferences dialog for the whole application */
 void
 properties (GtkWidget *toplevel)
 {
-        static GnomeHelpMenuEntry help_entry = { NULL, "properties" };
-
-	help_entry.name = gnome_app_id;
-
 	if (prop_win)
 		return;
 
@@ -730,17 +757,16 @@ properties (GtkWidget *toplevel)
 	create_alarm_page ();
 
 	gtk_signal_connect (GTK_OBJECT (prop_win), "destroy",
-			    (GtkSignalFunc) prop_cancel, NULL);
+			    GTK_SIGNAL_FUNC (prop_cancel), NULL);
 
 	gtk_signal_connect (GTK_OBJECT (prop_win), "delete_event",
-			    (GtkSignalFunc) prop_cancel, NULL);
+			    GTK_SIGNAL_FUNC (prop_cancel), NULL);
 
 	gtk_signal_connect (GTK_OBJECT (prop_win), "apply",
-			    (GtkSignalFunc) prop_apply, NULL);
+			    GTK_SIGNAL_FUNC (prop_apply), NULL);
 
 	gtk_signal_connect (GTK_OBJECT (prop_win), "help",
-			    GTK_SIGNAL_FUNC (gnome_help_pbox_display),
-			    &help_entry);
+			    GTK_SIGNAL_FUNC (prop_help), NULL);
 
 	gtk_widget_show_all (prop_win);
 }
@@ -759,8 +785,8 @@ parse_color_spec (char *spec, int *r, int *g, int *b)
 {
 	g_return_if_fail (spec != NULL);
 	g_return_if_fail (r != NULL);
-	g_return_if_fail (r != NULL);
-	g_return_if_fail (r != NULL);
+	g_return_if_fail (g != NULL);
+	g_return_if_fail (b != NULL);
 
 	if (sscanf (spec, "#%04x%04x%04x", r, g, b) != 3) {
 		g_warning ("Invalid color specification %s, returning black", spec);
@@ -898,7 +924,7 @@ prop_store_alarm_default_values (CalendarAlarm* alarm)
 }
 	
 static void
-prop_apply_alarms ()
+prop_apply_alarms (void)
 {
 	int i;
 	for (i=0; i < 4; i++)
