@@ -104,6 +104,7 @@ quick_view_map_event (GtkWidget *widget, GdkEventAny *event)
 /* Creates the items corresponding to a single calendar object.  Takes in the y position of the
  * items to create and returns the y position of the next item to create.  Also takes in the current
  * maximum width for items and returns the new maximum width.
+ * This is used in the popup-window in the year view
  */
 void
 create_items_for_event (QuickView *qv, CalendarObject *co, double *y, double *max_width)
@@ -130,7 +131,11 @@ create_items_for_event (QuickView *qv, CalendarObject *co, double *y, double *ma
 		strftime (end, sizeof (end), "%H:%M", &end_tm);
 	}
 
-	str = g_strconcat (start, " - ", end, " ", co->ico->summary, NULL);
+	if (co->ico->allday) {
+		str = g_strconcat (co->ico->summary, NULL);
+	} else {
+		str = g_strconcat (start, " - ", end, " ", co->ico->summary, NULL);
+	}
 
 	item = gnome_canvas_item_new (gnome_canvas_root (canvas),
 				      gnome_canvas_text_get_type (),
