@@ -19,7 +19,102 @@
 
 #include "address-conduit.h"
 
-#define CONDUIT_VERSION  "0.3"
+/* #define AC_DEBUG */
+#ifdef __GNUC__
+#  ifdef AC_DEBUG
+#    define LOG(args...) g_log (G_LOG_DOMAIN, \
+                                   G_LOG_LEVEL_MESSAGE, \
+                                   "address: "##args)
+#  else /* !AC_DEBUG */
+#    define LOG(args...)
+#  endif /* AC_DEBUG */
+#else /* !__GNUC__ */
+static void LOG(gchar *mesg, ...);
+#endif /* __GNUC__ */
+
+#define CONDUIT_VERSION  "0.5"
+
+#define OBJ_DATA_CONDUIT "conduit_data"
+#define OBJ_DATA_CONFIG  "conduit_config"
+#define CONFIG_PREFIX    "/gnome-pilot.d/address-conduit/Pilot_%u/"
+#define OBJ_DATA_OLDCONFIG  "conduit_oldconfig"
+#define OBJ_DATA_CONFIG_WINDOW  "config_window"
+
+#define GET_CONDUIT_CFG(s) ((ConduitCfg*)gtk_object_get_data(GTK_OBJECT(s),OBJ_DATA_CONFIG))
+#define GET_CONDUIT_DATA(s) ((ConduitData*)gtk_object_get_data(GTK_OBJECT(s),OBJ_DATA_CONDUIT))
+#define GET_CONDUIT_OLDCFG(s) ((ConduitCfg*)gtk_object_get_data(GTK_OBJECT(s),OBJ_DATA_OLDCONFIG))
+#define GET_CONDUIT_WINDOW(s) ((GtkWidget*)gtk_object_get_data(GTK_OBJECT(s),OBJ_DATA_CONFIG_WINDOW))
+
+static void 
+load_configuration(ConduitCfg **c,guint32 pilotId) 
+{
+	gchar prefix[256];
+	g_return_if_fail(c!=NULL);
+	
+	g_snprintf(prefix,255,CONFIG_PREFIX,pilotId);
+ 
+	*c = g_new0(ConduitCfg,1);
+	gnome_config_push_prefix(prefix);
+	(*c)->sync_type = GnomePilotConduitSyncTypeCustom; /* this will be reset by capplet */
+	(*c)->filename = gnome_config_get_string("filename");
+	(*c)->open_secret = gnome_config_get_bool("open_secret=FALSE");
+	gnome_config_pop_prefix();
+	
+	if((*c)->filename==NULL) {
+		(*c)->filename=g_strdup_printf("%s/.gnome/GnomeCard.gcrd",
+		g_get_home_dir ());
+	} 
+	(*c)->pilotId = pilotId;
+}
+
+static void 
+save_configuration(ConduitCfg *c) 
+{
+	gchar prefix[256];
+
+	g_return_if_fail(c!=NULL);
+	g_snprintf(prefix,255,CONFIG_PREFIX,c->pilotId);
+	
+	gnome_config_push_prefix(prefix);
+	gnome_config_set_string("filename",c->filename);
+	gnome_config_set_bool("open_secret",c->open_secret);
+	gnome_config_pop_prefix();
+	
+	gnome_config_sync();
+	gnome_config_drop_all();
+}
+
+static void 
+copy_configuration(ConduitCfg *d, ConduitCfg *c)
+{
+	g_return_if_fail(c!=NULL);
+	g_return_if_fail(d!=NULL);
+	d->sync_type=c->sync_type;
+	if(d->filename) g_free(d->filename);
+	d->filename = g_strdup(c->filename);
+	d->open_secret = c->open_secret;
+	d->pilotId = c->pilotId;
+}
+
+static ConduitCfg*
+dupe_configuration(ConduitCfg *c) 
+{
+	ConduitCfg *d;
+	g_return_val_if_fail(c!=NULL,NULL);
+	d = g_new0(ConduitCfg,1);
+	copy_configuration(d,c);
+	return d;
+}
+
+
+static void 
+destroy_configuration(ConduitCfg **c) 
+{
+	g_return_if_fail(c!=NULL);
+	if((*c)->filename) g_free((*c)->filename);
+	g_free(*c);
+	*c = NULL;
+}
 
 /************************************
   Address field index:
@@ -63,7 +158,7 @@ static enum PhoneType phone_type[]= {
 	PHONE_HOME,
 	PHONE_FAX,
 	PHONE_PREF,   /* TODO: What to do with "Other"? */
-	-1,           /* email */
+	0,           /* email */
 	PHONE_PREF,
 	PHONE_PAGER,
 	PHONE_CELL
@@ -163,6 +258,8 @@ iterate_foreach(GCardLocalRecord *local,IterateData *d)
 		if(d->archived != local->local.archived) accept = FALSE;
 	if(d->flag>=0)
 		if(d->flag != local->local.attr) accept = FALSE;
+
+	if(local->ignore == TRUE) accept = FALSE;
 	
 	if(accept) { 
 		if(d->prev) 
@@ -198,6 +295,19 @@ str_addr_to_card(gchar* s)
 	return g_strdup(s);
 }
 
+static gboolean
+changed_since_last_sync(Card *card, GnomePilotConduitStandardAbs *abs)
+{
+	if (card->rev.prop.used) {
+		time_t syncTime, revTime;
+		syncTime = GET_CONDUIT_DATA(abs)->dbi->pu->lastSyncDate;
+		revTime = mktime(&card->rev.tm)-timezone;
+		LOG("Comparing rev time %lu with sync time %lu",revTime,syncTime);
+		if (revTime > syncTime) return TRUE;
+	}
+	return FALSE;
+}
+
 static void 
 load_foreach(Card * card, GnomePilotConduitStandardAbs *abs) 
 {
@@ -273,16 +383,18 @@ load_foreach(Card * card, GnomePilotConduitStandardAbs *abs)
 	if(card->uid.prop.used) {
 		local->local.ID=atoi(card->uid.str);
 	}
-	/* TODO: Figure out Modified and Deleted records. HOW??? */
+	/* TODO: Figure out Deleted records. HOW??? */
         if(local->local.ID==0) {
 		local->local.attr = GnomePilotRecordNew;
+	} else if(changed_since_last_sync(card,abs)) {
+		local->local.attr = GnomePilotRecordModified;
 	}
 	if(card->categories.prop.used) {
 		local->category=convert_category(card->categories.str,abs);
 	}
 
 	/* TODO: Extention fields to keep our private info */
-	
+
 }
 
 /** loads the records into the abs structure */
@@ -319,6 +431,7 @@ backup_file(GnomePilotConduitStandardAbs *abs)
 	struct stat s;
 	
 	real_fname=GET_CONDUIT_CFG(abs)->filename;
+	g_return_if_fail(real_fname!=0);
 
 	bak_fname = g_malloc0 (strlen (real_fname) + 2);
 	sprintf (bak_fname, "%s~", real_fname);
@@ -345,7 +458,12 @@ spool_records(GnomePilotConduitStandardAbs *abs)
 	backup_file(abs);	
 	/* now write the file out */
 	fp = fopen(GET_CONDUIT_CFG(abs)->filename,"w");
-	g_return_if_fail(fp!=0);
+	if(fp==0) {
+		g_warning(_("Unable to open file: %s"),GET_CONDUIT_CFG(abs)->filename);
+		gnome_pilot_conduit_send_error(GNOME_PILOT_CONDUIT(abs),
+					       _("Unable to open file: %s"),GET_CONDUIT_CFG(abs)->filename);
+		return;
+	}
 	g_list_foreach(GET_CONDUIT_DATA(abs)->records,(GFunc)spool_foreach,fp);
 	fclose(fp);
 }
@@ -360,9 +478,8 @@ pre_sync(GnomePilotConduit *c, GnomePilotDBInfo *dbi)
 	g_message("GnomeCard conduit v %s",CONDUIT_VERSION);
 	LOG("PreSync");
 
-	GET_CONDUIT_DATA(c)->dbi=dbi;
+	GET_CONDUIT_DATA (c)->dbi = dbi;
   
-	load_records((GnomePilotConduitStandardAbs*)c); 
 	buf = (unsigned char*)g_malloc(0xffff);
 	if((l=dlp_ReadAppBlock(dbi->pilot_socket,dbi->db_handle,0,(unsigned char *)buf,0xffff))<0) {
 		LOG("dlp_ReadAppBlock(...) failed");
@@ -372,9 +489,11 @@ pre_sync(GnomePilotConduit *c, GnomePilotDBInfo *dbi)
 	unpack_AddressAppInfo(&(GET_CONDUIT_DATA(c)->ai),buf,l);
 	g_free(buf);
 
+	load_records((GnomePilotConduitStandardAbs*)c); 
+
 	/* If local store is empty force the slow sync. */
 	if(g_list_length(GET_CONDUIT_DATA(c)->records)==0){
-		gnome_pilot_conduit_standard_set_slow((GnomePilotConduitStandard*)c);
+		gnome_pilot_conduit_standard_set_slow(GNOME_PILOT_CONDUIT_STANDARD (c), TRUE);
 	}
 
 	return 0;
@@ -610,17 +729,6 @@ store_remote (GnomePilotConduitStandardAbs *abs,
 	return 0;
 }
 
-static gint
-clear_status_archive_local (GnomePilotConduitStandardAbs *abs,
-			    GCardLocalRecord *local,
-			    gpointer data)
-{
-	LOG("ClearStatusArchiveLocal");
-	g_return_val_if_fail(local!=NULL,-1);
-	local->local.archived=0;
-	return 0;
-}
-
 static gint
 iterate (GnomePilotConduitStandardAbs *abs,
 	 GCardLocalRecord **local,
@@ -688,19 +796,8 @@ set_status (GnomePilotConduitStandardAbs *abs,
 {
 	LOG("SetStatus");
 	g_return_val_if_fail(local!=NULL,-1);
-	local->local.attr = status; 
-	return 0;
-}
-
-static gint
-set_archived (GnomePilotConduitStandardAbs *abs,
-	      GCardLocalRecord *local,
-	      gint archived,
-	      gpointer data)
-{
-	LOG("SetArchived");
-	g_return_val_if_fail(local!=NULL,-1);
-	local->local.archived = archived; 
+	local->local.attr = status;
+	if(status==GnomePilotRecordDeleted) local->ignore=TRUE;	
 	return 0;
 }
 
@@ -834,35 +931,170 @@ transmit (GnomePilotConduitStandardAbs *abs,
 	return 0;
 }
 
+static GtkWidget
+*createCfgWindow(GnomePilotConduit* conduit)
+{
+	GtkWidget *vbox, *table;
+	GtkWidget *label;
+	GtkWidget *button;	
+	GtkWidget *entry;
+
+	vbox = gtk_vbox_new(FALSE, GNOME_PAD);
+
+	table = gtk_table_new(2, 2, FALSE);
+	gtk_table_set_row_spacings (GTK_TABLE(table), 4);
+	gtk_table_set_col_spacings (GTK_TABLE(table), 10);
+	gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, GNOME_PAD);
+
+	label = gtk_label_new(_("Open secret entries"));
+	gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 0, 1);
+
+	button = gtk_check_button_new();
+	gtk_object_set_data(GTK_OBJECT(vbox), "open_secret", button);
+	gtk_table_attach_defaults(GTK_TABLE(table), button, 1, 2, 0, 1);
+
+	label = gtk_label_new(_("Filename"));
+	gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 1, 1, 2);
+
+	entry = gtk_entry_new ();
+	gtk_object_set_data(GTK_OBJECT(vbox), "filename", entry);
+	gtk_table_attach_defaults(GTK_TABLE(table), entry, 1, 2, 1, 2);
+
+	return vbox;
+}
+
+static void
+setOptionsCfg(GtkWidget *pilotcfg, ConduitCfg *state)
+{
+	GtkWidget *open_secret;
+	GtkWidget *filename;
+
+	filename = gtk_object_get_data (GTK_OBJECT (pilotcfg), "filename");
+	open_secret = gtk_object_get_data (GTK_OBJECT (pilotcfg), "open_secret");
+
+	g_assert(filename != NULL);
+	g_assert(open_secret != NULL);
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(open_secret), state->open_secret);
+	gtk_entry_set_text (GTK_ENTRY (filename), state->filename);
+}
+
+
+static void
+readOptionsCfg(GtkWidget *pilotcfg, ConduitCfg *state)
+{
+	GtkWidget *open_secret;
+	GtkWidget *filename;
+
+	filename = gtk_object_get_data (GTK_OBJECT (pilotcfg), "filename");
+	open_secret = gtk_object_get_data (GTK_OBJECT (pilotcfg), "open_secret");
+
+	g_assert(filename != NULL);
+	g_assert(open_secret != NULL);
+
+	state->open_secret = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (open_secret));
+	g_free (state->filename);
+	state->filename = g_strdup (gtk_entry_get_text (GTK_ENTRY (filename)));
+}
+
+static gint
+create_settings_window (GnomePilotConduit *conduit, GtkWidget *parent, gpointer data)
+{
+	GtkWidget *cfgWindow;
+	cfgWindow = createCfgWindow (conduit);
+	gtk_container_add (GTK_CONTAINER (parent), cfgWindow);
+	gtk_widget_show_all (cfgWindow);
+
+	gtk_object_set_data (GTK_OBJECT (conduit), OBJ_DATA_CONFIG_WINDOW, cfgWindow);
+	setOptionsCfg (GET_CONDUIT_WINDOW (conduit), GET_CONDUIT_CFG (conduit));
+
+	return 0;
+}
+
+static void
+display_settings (GnomePilotConduit *conduit, 
+		  gpointer data)
+{
+	setOptionsCfg (GET_CONDUIT_WINDOW (conduit), GET_CONDUIT_CFG (conduit));
+}
+
+static void
+save_settings (GnomePilotConduit *conduit, 
+	       gpointer data)
+{
+	readOptionsCfg (GET_CONDUIT_WINDOW (conduit), GET_CONDUIT_CFG (conduit));
+	save_configuration (GET_CONDUIT_CFG (conduit));
+}
+
+static void
+revert_settings  (GnomePilotConduit *conduit, gpointer data)
+{
+	ConduitCfg *cfg,*cfg2;
+	cfg2= GET_CONDUIT_OLDCFG(conduit);
+	cfg = GET_CONDUIT_CFG(conduit);
+	save_configuration (cfg2);
+	copy_configuration (cfg,cfg2);
+	setOptionsCfg(GET_CONDUIT_WINDOW(conduit),cfg);
+}
+
 GnomePilotConduit *
 conduit_get_gpilot_conduit (guint32 pilotId)
 {
 	GtkObject *retval;
 
 	ConduitData *cd = g_new0(ConduitData,1);
-	ConduitCfg *cc;
+	ConduitCfg *cfg, *cfg2;
 	
 	cd->records=NULL;
   
+	load_configuration(&cfg,pilotId);
+	cfg2 = dupe_configuration (cfg);
+
 	retval = gnome_pilot_conduit_standard_abs_new ("AddressDB", 0x61646472);
 	g_assert (retval != NULL);
-	gnome_pilot_conduit_construct(GNOME_PILOT_CONDUIT(retval),"address");
+
+	gtk_object_set_data (GTK_OBJECT(retval), OBJ_DATA_CONDUIT, cd);
+	gtk_object_set_data (GTK_OBJECT(retval), OBJ_DATA_CONFIG, cfg);
+	gtk_object_set_data (GTK_OBJECT(retval), OBJ_DATA_OLDCONFIG, cfg2);
+	gtk_object_set_data (GTK_OBJECT(retval), OBJ_DATA_CONDUIT, cd);
+	
+	if(cfg->filename==NULL) {
+		g_warning(_("No filename specified. Please run address conduit capplet first."));
+		gnome_pilot_conduit_error(GNOME_PILOT_CONDUIT(retval),
+					  _("No filename specified. Please run address conduit capplet first."));
+		/* FIXME: the following is probably the right way to go, 
+		   but with current state it doesn't work. (capplet wouldn't start up)
+		   destroy_configuration(&cc);
+		   return NULL;
+		*/
+	} 
 
 	
 	LOG("creating GnomeCard conduit");
 
 	g_assert (retval != NULL);
+	gtk_signal_connect (retval, 
+			    GNOME_PILOT_CONDUIT_SIGNAL_CREATE_SETTINGS_WINDOW (create_settings_window),
+			    NULL);
+	gtk_signal_connect (retval, 
+			    GNOME_PILOT_CONDUIT_SIGNAL_DISPLAY_SETTINGS (display_settings),
+			    NULL);
+	gtk_signal_connect (retval,
+			    GNOME_PILOT_CONDUIT_SIGNAL_SAVE_SETTINGS (save_settings),
+			    NULL);
+	gtk_signal_connect (retval, 
+			    GNOME_PILOT_CONDUIT_SIGNAL_REVERT_SETTINGS (revert_settings),
+			    NULL);
+	
 	gtk_signal_connect (retval, "match_record", (GtkSignalFunc) match_record, NULL);
 	gtk_signal_connect (retval, "free_match", (GtkSignalFunc) free_match, NULL);
 	gtk_signal_connect (retval, "archive_local", (GtkSignalFunc) archive_local, NULL);
 	gtk_signal_connect (retval, "archive_remote", (GtkSignalFunc) archive_remote, NULL);
 	gtk_signal_connect (retval, "store_remote", (GtkSignalFunc) store_remote, NULL);
-	gtk_signal_connect (retval, "clear_status_archive_local", (GtkSignalFunc) clear_status_archive_local, NULL);
 	gtk_signal_connect (retval, "iterate", (GtkSignalFunc) iterate, NULL);
 	gtk_signal_connect (retval, "iterate_specific", (GtkSignalFunc) iterate_specific, NULL);
 	gtk_signal_connect (retval, "purge", (GtkSignalFunc) purge, NULL);
 	gtk_signal_connect (retval, "set_status", (GtkSignalFunc) set_status, NULL);
-	gtk_signal_connect (retval, "set_archived", (GtkSignalFunc) set_archived, NULL);
 	gtk_signal_connect (retval, "set_pilot_id", (GtkSignalFunc) set_pilot_id, NULL);
 	gtk_signal_connect (retval, "compare", (GtkSignalFunc) compare, NULL);
 	gtk_signal_connect (retval, "compare_backup", (GtkSignalFunc) compare_backup, NULL);
@@ -871,12 +1103,10 @@ conduit_get_gpilot_conduit (guint32 pilotId)
 	gtk_signal_connect (retval, "transmit", (GtkSignalFunc) transmit, NULL);
 	gtk_signal_connect (retval, "pre_sync", (GtkSignalFunc) pre_sync, NULL);
 
-	load_configuration(&cc,pilotId);
-	gtk_object_set_data(GTK_OBJECT(retval),OBJ_DATA_CONFIG,cc);
-	gtk_object_set_data(GTK_OBJECT(retval),OBJ_DATA_CONDUIT,cd);
-	
-	if(cc->open_secret) gnome_pilot_conduit_standard_abs_set_db_open_mode(GNOME_PILOT_CONDUIT(retval),
-									      dlpOpenReadWrite|dlpOpenSecret);
+	if(cfg->open_secret) {
+		gnome_pilot_conduit_standard_abs_set_db_open_mode(GNOME_PILOT_CONDUIT_STANDARD_ABS(retval),
+								  dlpOpenReadWrite|dlpOpenSecret);
+	}
 
 	return GNOME_PILOT_CONDUIT (retval);
 }
@@ -896,3 +1126,17 @@ conduit_destroy_gpilot_conduit (GnomePilotConduit *conduit)
 }
 
 
+/* non-gcc compatibility: */
+#ifndef __GNUC__
+static void LOG(gchar *mesg, ...)
+{
+#ifdef AC_DEBUG
+	va_list ap;
+	gchar *format = g_strconcat("address: ", mesg, NULL);
+	va_start(ap, mesg);
+	g_logv(G_LOG_DOMAIN, G_LOG_LEVEL_MESSAGE, format, ap);
+	va_end(ap);
+	g_free(format);
+#endif
+}
+#endif /* __GNUC__ */
