@@ -17,9 +17,6 @@
 #include "card.h"
 
 
-#define OBJ_DATA_CONDUIT "conduit_data"
-#define OBJ_DATA_CONFIG  "conduit_config"
-#define CONFIG_PREFIX    "/gnome-pilot.d/address-conduit/Pilot_%u/"
 
 
 typedef struct _GCardLocalRecord GCardLocalRecord;
@@ -40,9 +37,6 @@ struct _ConduitData {
 	GnomePilotDBInfo *dbi;
 };
 
-#define GET_CONDUIT_CFG(s) ((ConduitCfg*)gtk_object_get_data(GTK_OBJECT(s),OBJ_DATA_CONFIG))
-#define GET_CONDUIT_DATA(s) ((ConduitData*)gtk_object_get_data(GTK_OBJECT(s),OBJ_DATA_CONDUIT))
-
 typedef struct IterateData {
 	int flag;
 	int archived;
