@@ -121,11 +121,11 @@ static void gnomecard_prop_apply(GtkWidget *widget, int page)
 	crd->org.unit3 = MY_STRDUP(gtk_entry_get_text(GTK_ENTRY(ce->org3)));
 	crd->org.unit4 = MY_STRDUP(gtk_entry_get_text(GTK_ENTRY(ce->org4)));
 #else
-	crd->role.str  = MY_STRDUP("");
-	crd->org.unit1 = MY_STRDUP("");
-        crd->org.unit2 = MY_STRDUP("");
-        crd->org.unit3 = MY_STRDUP("");
-        crd->org.unit4 = MY_STRDUP("");
+	crd->role.str  = NULL;
+	crd->org.unit1 = NULL;
+	crd->org.unit2 = NULL;
+	crd->org.unit3 = NULL;
+	crd->org.unit4 = NULL;
 #endif	
 	MY_FREE(crd->categories.str);
 	MY_FREE(crd->comment.str);
@@ -703,8 +703,6 @@ colsetup_list_selected(GtkCList *list, gint row, gint column,
 
     coltype = GPOINTER_TO_INT(gtk_clist_get_row_data(GTK_CLIST(edit->srcList), row));
 
-    g_message("User selected %s", getColumnNameFromType(coltype));
-
     if (coltype != COLTYPE_EMAIL &&
 	coltype != COLTYPE_PHONE &&
 	g_list_find(edit->selHdrs, GINT_TO_POINTER(coltype)))
@@ -724,16 +722,13 @@ colsetup_addpress(GtkWidget *widget, gpointer data)
 	edit = (ColumnHdrEditor *)data;
 	if (GTK_CLIST(edit->srcList)->selection) {
 		gint row, row2;
-		const gchar *rowtxt[2];
+		gchar *rowtxt[2];
 		
 		row = GPOINTER_TO_INT
 		  (GTK_CLIST(edit->srcList)->selection->data);
 		
-		g_message("adding row # %d",row);
-		
 		coltype = GPOINTER_TO_INT
 		  (gtk_clist_get_row_data(GTK_CLIST(edit->srcList), row));
-		g_message("coltype is %d",coltype);
 		
 		/* add to end of the clist, selected list if not already selected */
 		if (coltype == COLTYPE_EMAIL ||
@@ -787,7 +782,6 @@ colsetup_delpress(GtkWidget *widget, gpointer data)
 	    row2 = GPOINTER_TO_INT(GTK_CLIST(edit->srcList)->selection->data);
 	    coltype2 = GPOINTER_TO_INT(gtk_clist_get_row_data(GTK_CLIST(edit->srcList), row2));
 
-	    g_message("coltype coltype2 %d %d",coltype, coltype2);
 	    if (coltype2 == coltype)
 		gtk_widget_set_sensitive(edit->addButton, 1);
 	}
@@ -1008,7 +1002,7 @@ gnomecard_setup(GtkWidget *widget, gpointer data)
 	/* fill in the two lists */
 	edit->allHdrs = getAllColumnHdrs();
 	for (l=edit->allHdrs, i=0; l; l=l->next, i++) {
-	    const gchar *rowtxt[2];
+	    gchar *rowtxt[2];
 
 	    rowtxt[0] = _(((ColumnHeader *)(l->data))->colname);
 	    rowtxt[1] = NULL;
@@ -1025,7 +1019,7 @@ gnomecard_setup(GtkWidget *widget, gpointer data)
 				   "ColumnHeaders");
 	edit->selHdrs = NULL;
 	for (l=cols; l; l=l->next) {
-	    const gchar *rowtxt[2];
+	    gchar *rowtxt[2];
 	    gint  row;
 
 	    hdr = (ColumnHeader *)l->data;
@@ -1434,7 +1428,9 @@ extern void gnomecard_find_card_call(GtkWidget *widget, gpointer data)
 	p->back = check = gtk_check_button_new_with_label(_("Find Backwards"));
 	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(check), gnomecard_find_back);
 	gtk_box_pack_end(GTK_BOX(hbox), check, FALSE, FALSE, 0);
-	
+
+	gtk_window_set_focus(GTK_WINDOW(w), p->entry);
+
 	gtk_widget_show_all(GNOME_DIALOG(w)->vbox);
 	gtk_widget_show(w);
 }
