@@ -208,10 +208,10 @@ static void emaillist_edit (GtkWidget *w, gpointer data)
         CardEMail *email;
 	char *text;
 	
-	g_assert (p->row != -1);
-	
 	p = (EMailList *) data;
 	
+	g_assert (p->row != -1);
+	
 	text = gtk_entry_get_text(GTK_ENTRY(p->data));
 	if (*text == 0)
 	  return;
@@ -500,7 +500,10 @@ extern EMailList *emaillist_create_edit_page (Card *crd, GnomePropertyBox *box)
  	gtk_signal_connect(GTK_OBJECT(button), "clicked",
 			   GTK_SIGNAL_FUNC(emaillist_down), p);
 	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, GNOME_PAD_SMALL);
-	
+
+	/* Select the Internet radio button. */
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (p->type[5]), TRUE);
+
 	emaillist_copy_crd_emails (p, crd);
 	
 	emaillist_unselect (p);
