@@ -68,6 +68,7 @@ GnomeApp *gnomecard_window;
 
 GtkCList *gnomecard_list=NULL;
 GtkWidget *cardlist_scrollwin = NULL;
+GtkWidget *hpaned = NULL;
 
 gint     gnomecard_selected_row=0;
 GtkWidget *tb_next, *tb_prev, *tb_first, *tb_last;
@@ -75,17 +76,16 @@ GtkWidget *tb_edit, *tb_find, *tb_save, *tb_del;
 GtkWidget *menu_next, *menu_prev, *menu_first, *menu_last;
 GtkWidget *menu_edit, *menu_find, *menu_save, *menu_del;
 
-GList *gnomecard_crds=NULL;
-GList *gnomecard_curr_crd=NULL;
+GList *gnomecard_crds = NULL;
+GList *gnomecard_curr_crd = NULL;
 
-char *gnomecard_fname;
-char *gnomecard_find_str;
+gchar *gnomecard_fname = NULL;
+gchar *gnomecard_find_str = NULL;
 gboolean gnomecard_find_sens;
 gboolean gnomecard_find_back;
-/* NOTE USED gint gnomecard_def_data; */
 
 gboolean gnomecard_changed;
-gboolean gnomecard_found;                 /* yeah... pretty messy. (fixme) */
+gboolean gnomecard_found;                 /* yeah... pretty messy. (FIXME) */
 
 
 static void gnomecard_toggle_card_view(GtkWidget *w, gpointer data);
@@ -387,8 +387,8 @@ gnomecard_new_card(GtkWidget *widget, gpointer data)
 	GList *last;
 	
 	crd = card_new();
-	gnomecard_add_card_to_list(crd);
 	gnomecard_crds = g_list_append(gnomecard_crds, crd);
+	gnomecard_add_card_to_list(crd);
 	
 	last = g_list_last(gnomecard_crds);
 	gnomecard_edit(last);
@@ -421,12 +421,14 @@ void gnomecard_last_card(GtkWidget *widget, gpointer data)
 void gnomecard_quit(GtkWidget *widget, gpointer data)
 {
 	if (gnomecard_destroy_cards ()) {
-		int x, y;
+		int x, y, pos;
 	
 		x = GTK_WIDGET (gnomecard_window)->allocation.width;
 		y = GTK_WIDGET (gnomecard_window)->allocation.height;
+		pos = GTK_PANED(hpaned)->child1_size;
 		gnome_config_set_int("/GnomeCard/CardDisplay/width", x);
 		gnome_config_set_int("/GnomeCard/CardDisplay/height", y);
+		gnome_config_set_int("/GnomeCard/CardDisplay/position", pos);
 		gnome_config_sync ();
 		
 		gtk_widget_destroy(GTK_WIDGET (gnomecard_window));
@@ -436,11 +438,8 @@ void gnomecard_quit(GtkWidget *widget, gpointer data)
 
 gint gnomecard_delete(GtkWidget *w, GdkEvent *e, gpointer data)
 {
-	if (gnomecard_destroy_cards()) {
-		gtk_widget_destroy(GTK_WIDGET (gnomecard_window));
-		gtk_main_quit();
-	}
-	  
+	gnomecard_quit(w, data);
+
 	return TRUE;
 }
 
@@ -515,23 +514,23 @@ GnomeUIInfo gomenu[] = {
 	
 GnomeUIInfo sortradios[] = {
 	
-	{GNOME_APP_UI_ITEM, N_("By Card Name"), "",
+	{GNOME_APP_UI_ITEM, N_("By Card Name"), N_("Sorts the card list by the card name"),
 	 gnomecard_sort_cards, (gpointer) COLTYPE_CARDNAME, NULL,
 	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
 	
-	{GNOME_APP_UI_ITEM, N_("By Name"), "",
+	{GNOME_APP_UI_ITEM, N_("By Name"), N_("Sorts the card list by the name of the person"),
 	 gnomecard_sort_cards, (gpointer) COLTYPE_FULLNAME, NULL,
 	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
 	
-	{GNOME_APP_UI_ITEM, N_("By Last Name"), "",
+	{GNOME_APP_UI_ITEM, N_("By Last Name"), N_("Sorts the card list by the last name of the person"),
 	 gnomecard_sort_cards, (gpointer) COLTYPE_LASTNAME, NULL,
 	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
 	
-	{GNOME_APP_UI_ITEM, N_("By E-mail"), "",
+	{GNOME_APP_UI_ITEM, N_("By E-mail"), N_("Sorts the card list by the e-mail address of the person"),
 	 gnomecard_sort_cards, (gpointer) COLTYPE_EMAIL, NULL,
 	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
 
-	{GNOME_APP_UI_ITEM, N_("By Organization"), "",
+	{GNOME_APP_UI_ITEM, N_("By Organization"), N_("Sorts the card list by the name of the organization"),
 	 gnomecard_sort_cards, (gpointer) COLTYPE_ORG, NULL,
 	GNOME_APP_PIXMAP_NONE, NULL, 0, 0, NULL},
 	
@@ -706,9 +705,9 @@ void gnomecard_init(void)
 {
 	GtkWidget *scrollwin;
         GnomeAppBar *appbar;
-	GtkWidget *canvas, *hbox;
+	GtkWidget *canvas;
 	gchar *s;
-	gint ncol, i, x, y;
+	gint ncol, i, x, y, pos;
 
 	/* hard coded column headers */
 	ColumnType defaulthdrs[] = {COLTYPE_CARDNAME, COLTYPE_EMAIL, 
@@ -736,18 +735,17 @@ void gnomecard_init(void)
 			      
 	gtk_signal_connect(GTK_OBJECT(gnomecard_window), "delete_event",
 			   GTK_SIGNAL_FUNC(gnomecard_delete), NULL);
-	
-	hbox = gtk_hbox_new(FALSE, 0);
-/*	gtk_paned_set_gutter_size (GTK_PANED (hpaned), GNOME_PAD_BIG);
-	gtk_widget_show (hpaned);*/
-	
+
+	hpaned = gtk_hpaned_new();
+	gtk_paned_set_gutter_size (GTK_PANED (hpaned), GNOME_PAD_BIG);
+	gtk_widget_show (hpaned);
+
 	gnome_app_create_menus(GNOME_APP(gnomecard_window), mainmenu);
 
 	gnome_app_install_menu_hints(GNOME_APP(gnomecard_window), mainmenu);
 	gnome_app_create_toolbar(GNOME_APP(gnomecard_window), toolbar);
 
-	gnome_app_set_contents(GNOME_APP(gnomecard_window), hbox);
-/*	gnome_app_set_contents(GNOME_APP(gnomecard_window), hpaned);*/
+	gnome_app_set_contents(GNOME_APP(gnomecard_window), hpaned);
 
 	cardlist_scrollwin = scrollwin = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrollwin),
@@ -788,8 +786,7 @@ void gnomecard_init(void)
 /*	gtk_widget_set_usize (scrollwin, 200, 0);*/
 	gtk_widget_show(scrollwin);
 	
-	gtk_box_pack_start(GTK_BOX(hbox), cardlist_scrollwin, TRUE, TRUE, 0);
-/*	gtk_paned_pack1 (GTK_PANED (hpaned), scrollwin, TRUE, FALSE);*/
+	gtk_paned_pack1 (GTK_PANED (hpaned), cardlist_scrollwin, TRUE, TRUE);
 
 	/* add canvas */
 	gtk_widget_push_visual(gdk_imlib_get_visual());
@@ -802,8 +799,9 @@ void gnomecard_init(void)
 	gtk_container_add(GTK_CONTAINER(scrollwin), canvas);
 	gtk_widget_show(canvas);
 	gtk_widget_show(scrollwin);
-	gtk_box_pack_start(GTK_BOX(hbox), scrollwin, TRUE, TRUE, 0);
-/*	gtk_paned_pack2 (GTK_PANED (hpaned), scrollwin, TRUE, TRUE);*/
+	gtk_paned_pack2 (GTK_PANED (hpaned), scrollwin, TRUE, TRUE);
+	pos = gnome_config_get_int("/GnomeCard/CardDisplay/position=250");
+	gtk_paned_set_position(GTK_PANED (hpaned), pos);
 
 	/* no cards yet */
 	gnomecard_crds = NULL;
@@ -837,6 +835,11 @@ void gnomecard_init(void)
 	gtk_widget_show(GTK_WIDGET (gnomecard_window));
 }
 
+static const struct poptOption options [] = {
+	{ "filename", 'f', POPT_ARG_STRING, &gnomecard_fname, 0, N_("default file to load"), N_("filename") },
+	{ NULL, '\0', 0, NULL, 0 }
+};
+
 int main (int argc, char *argv[])
 {
 	CORBA_ORB orb;
@@ -850,10 +853,14 @@ int main (int argc, char *argv[])
 	textdomain(PACKAGE);
 
 	CORBA_exception_init(&ev);
-	orb = gnome_CORBA_init("gnomecard", VERSION, &argc, argv, GNORBA_INIT_SERVER_FUNC, &ev);
+	orb = gnome_CORBA_init_with_popt_table(
+			"gnomecard", VERSION,
+			&argc, argv,
+			options, 0, NULL,
+			GNORBA_INIT_SERVER_FUNC, &ev);
 	Exception (&ev);
 
-	poa = CORBA_ORB_resolve_initial_references(orb, "RootPOA", &ev);
+	poa = (PortableServer_POA)CORBA_ORB_resolve_initial_references(orb, "RootPOA", &ev);
 	Exception (&ev);
 
 	server = impl_gnome_PIM_vCard_server__create(poa, &ev);
@@ -866,11 +873,12 @@ int main (int argc, char *argv[])
 	Exception (&ev);
 
 	name_server = gnome_name_service_get ();
-	goad_server_register (name_server,
-                              server,
-                              "gnomecard",
-                              "object",
-			      &ev);
+	if (name_server != CORBA_OBJECT_NIL)
+		goad_server_register (name_server,
+                                      server,
+                                      "gnomecard",
+                                      "object",
+			              &ev);
 
 	gnomecard_init();
 	gtk_main();
