@@ -82,11 +82,10 @@ extern void gnomecard_init_pixes(void)
 
 extern void gnomecard_init_defaults(void)
 {
-	char *fname;
-	
 	gnomecard_find_sens = gnome_config_get_bool("/GnomeCard/find/sens=False");
 	gnomecard_find_back = gnome_config_get_bool("/GnomeCard/find/back=False");
 	gnomecard_find_str = gnome_config_get_string("/GnomeCard/find/str=");
-	gnomecard_fname = gnome_config_get_string("/GnomeCard/file/open=");
+	if (!gnomecard_fname)
+		gnomecard_fname = gnome_config_get_string("/GnomeCard/file/open=");
 }
 
