@@ -170,7 +170,7 @@ gnomecardFreeColTitles(GList *col)
 }
 
 
-GList *
+static GList *
 gnomecardCreateColValues(Card *crd, GList *cols)
 {
 	gchar *str;
@@ -219,7 +219,7 @@ gnomecardCreateColValues(Card *crd, GList *cols)
 	return l;
 }
 
-void
+static void
 gnomecardFreeColValues(GList *col)
 {
     g_list_foreach(col, (GFunc)g_free, NULL);
@@ -235,7 +235,7 @@ gnomecard_update_list(Card *crd)
 
     cols = gtk_object_get_data(GTK_OBJECT(gnomecard_list), "ColumnHeaders");
     if (!cols) {
-	g_message("gnomecard_add_card_to_list: col hdrs not defined");
+	g_message("gnomecard_update_list: col hdrs not defined");
 	return;
     }
     row = gtk_clist_find_row_from_data( gnomecard_list, crd);
