@@ -21,12 +21,27 @@
 
 #include <config.h>
 #include <gnome.h>
+#include <ctype.h>
 
 #include "gnomecard.h"
 #include "my.h"
 
 static void gnomecard_property_used(GtkWidget *w, gpointer data);
 
+extern char *my_cap (char *str) 
+{
+	int i;
+	
+	str = g_strdup (str);
+	
+	str[0] = toupper (str[0]);
+	
+	for (i = 1; i < strlen (str); i++)
+	  str[i] = tolower (str[i]);
+	
+	return str;
+}
+
 GtkWidget *
 my_gtk_entry_new(gint len, char *init)
 {
