@@ -32,30 +32,37 @@ struct pair
 };
 
 struct pair prop_lookup[] = {
-		{      VCFullNameProp, PROP_FNAME },
-		{          VCNameProp, PROP_NAME },
-		{         VCPhotoProp, PROP_PHOTO },
-		{     VCBirthDateProp, PROP_BDAY },
-		{           VCAdrProp, PROP_DELADDR },
-		{ VCDeliveryLabelProp, PROP_DELLABEL },
-		{     VCTelephoneProp, PROP_PHONE },
-		{  VCEmailAddressProp, PROP_EMAIL },
-		{        VCMailerProp, PROP_MAILER },
-		{      VCTimeZoneProp, PROP_TIMEZN },
-		{           VCGeoProp, PROP_GEOPOS },
-		{         VCTitleProp, PROP_TITLE },
-		{  VCBusinessRoleProp, PROP_ROLE },
-		{          VCLogoProp, PROP_LOGO },
-		{         VCAgentProp, PROP_AGENT },
-		{           VCOrgProp, PROP_ORG },
-		{    VCCategoriesProp, PROP_CATEGORIES },
-		{       VCCommentProp, PROP_COMMENT },
-		{   VCLastRevisedProp, PROP_REV },
-		{ VCPronunciationProp, PROP_SOUND },
-		{           VCURLProp, PROP_URL },
-		{  VCUniqueStringProp, PROP_UID },
-		{       VCVersionProp, PROP_VERSION },
-		{     VCPublicKeyProp, PROP_KEY },
+		{        VCFullNameProp, PROP_FNAME },
+		{            VCNameProp, PROP_NAME },
+		{           VCPhotoProp, PROP_PHOTO },
+		{       VCBirthDateProp, PROP_BDAY },
+		{             VCAdrProp, PROP_DELADDR },
+		{   VCDeliveryLabelProp, PROP_DELLABEL },
+		{       VCTelephoneProp, PROP_PHONE },
+		{    VCEmailAddressProp, PROP_EMAIL },
+		{          VCMailerProp, PROP_MAILER },
+		{        VCTimeZoneProp, PROP_TIMEZN },
+		{             VCGeoProp, PROP_GEOPOS },
+		{           VCTitleProp, PROP_TITLE },
+		{    VCBusinessRoleProp, PROP_ROLE },
+		{            VCLogoProp, PROP_LOGO },
+		{           VCAgentProp, PROP_AGENT },
+		{             VCOrgProp, PROP_ORG },
+		{      VCCategoriesProp, PROP_CATEGORIES },
+		{         VCCommentProp, PROP_COMMENT },
+		{     VCLastRevisedProp, PROP_REV },
+		{   VCPronunciationProp, PROP_SOUND },
+		{             VCURLProp, PROP_URL },
+		{    VCUniqueStringProp, PROP_UID },
+		{         VCVersionProp, PROP_VERSION },
+		{       VCPublicKeyProp, PROP_KEY },
+		{           VCValueProp, PROP_VALUE },
+		{        VCEncodingProp, PROP_ENCODING },
+		{ VCQuotedPrintableProp, PROP_QUOTED_PRINTABLE },
+		{            VC8bitProp, PROP_8BIT },
+		{          VCBase64Prop, PROP_BASE64 },
+		{        VCLanguageProp, PROP_LANG },
+		{         VCCharSetProp, PROP_CHARSET },
 		{ NULL, PROP_NONE} };
 
 struct pair addr_pairs[] = {
