@@ -22,17 +22,24 @@
 #ifndef __GNOMECARD_PHONELIST_H
 #define __GNOMECARD_PHONELIST_H
 
-#include "dialog.h"
-
-GtkWidget *gnomecard_create_phone_page(Card *crd, GnomeCardEditor *ce,
-				       GnomePropertyBox *box);
-void deletePhoneList(CardList *src);
-void copyPhoneList(CardList src, CardList *dest);
-void copyGUIToCurPhone(GnomeCardEditor *ce);
-void copyCurPhoneToGUI(GnomeCardEditor *ce);
-GList *findmatchPhoneType(GList *l, gint type);
-
+typedef struct
+{
+	GtkWidget *the_vbox;
+	
+	GtkWidget *type[13], *data, *clist;
+	GtkWidget *add, *edit, *del;
+	GtkWidget *up, *down;
+	
+	Card *crd;
+	GPtrArray *phone_array;
+	int row, num_rows;
+	GnomePropertyBox *prop_box;
+} PhoneList;
 
+extern PhoneList *phonelist_create_edit_page(Card *crd, GnomePropertyBox *box);
+extern void       phonelist_del_entries (PhoneList *p);
+extern GList     *phonelist_get_entries (PhoneList *p);
+extern GList     *phonelist_find_by_type (GList *l, gint type);
 
 #endif
 
