@@ -42,15 +42,13 @@ DFARS 252.227-7013 or 48 CFR 52.227-19, as applicable.
  * vobject, and convert a vobject into its textual representation.
  */
 
-#ifndef	 MWERKS
-#include <malloc.h>
-#endif
-
 #include "vobject.h"
+#include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
 #include <fcntl.h>
 
+#define USE_STRTBL
 
 #define NAME_OF(o)				o->id
 #define VALUE_TYPE(o)			o->valType
@@ -145,6 +143,7 @@ DLLEXPORT(void) deleteStr(const char *p)
 }
 
 
+#ifdef USE_STRTBL
 static StrItem* newStrItem(const char *s, StrItem *next)
 {
     StrItem *p = (StrItem*)malloc(sizeof(StrItem));
@@ -158,7 +157,7 @@ static void deleteStrItem(StrItem *p)
 {
     free((void*)p);
 }
-
+#endif
 
 /*----------------------------------------------------------------------
   The following function provide accesses to VObject's value.
@@ -612,6 +611,7 @@ DLLEXPORT(void) cleanVObjects(VObject *list)
 /*----------------------------------------------------------------------
   The following is a String Table Facilities.
   ----------------------------------------------------------------------*/
+#ifdef USE_STRTBL
 
 #define STRTBLSIZE 255
 
@@ -627,8 +627,11 @@ static unsigned int hashStr(const char *s)
     return h % STRTBLSIZE;
 }
 
+#endif
+
 DLLEXPORT(const char*) lookupStr(const char *s)
 {
+#ifdef USE_STRTBL
     StrItem *t;
     unsigned int h = hashStr(s);
     if ((t = strTbl[h]) != 0) {
@@ -643,10 +646,14 @@ DLLEXPORT(const char*) lookupStr(const char *s)
     s = dupStr(s,0);
     strTbl[h] = newStrItem(s,strTbl[h]);
     return s;
+#else
+  return dupStr(s, 0);
+#endif
 }
 
 DLLEXPORT(void) unUseStr(const char *s)
 {
+#ifdef USE_STRTBL
     StrItem *t, *p;
     unsigned int h = hashStr(s);
     if ((t = strTbl[h]) != 0) {
@@ -670,10 +677,14 @@ DLLEXPORT(void) unUseStr(const char *s)
 	    t = t->next;
 	    } while (t);
 	}
+#else
+  deleteStr (s);
+#endif
 }
 
 DLLEXPORT(void) cleanStrTbl()
 {
+#ifdef USE_STRTBL
     int i;
     for (i=0; i<STRTBLSIZE;i++) {
 	StrItem *t = strTbl[i];
@@ -686,6 +697,7 @@ DLLEXPORT(void) cleanStrTbl()
 	    } while (t);
 	strTbl[i] = 0;
 	}
+#endif
 }
 
 
@@ -1149,34 +1161,55 @@ static int writeBase64(OFile *fp, unsigned char *s, long len)
     return 1;
 }
 
+static void writeString(OFile *fp, const char *s)
+{
+    appendsOFile(fp,s);
+}
+
 static void writeQPString(OFile *fp, const char *s)
 {
+    char buf[4];
+    int count=0;
     const char *p = s;
+
     while (*p) {
-	if (*p == '\n') {
-	    if (p[1]) appendsOFile(fp,"=0A=");
-	    }
-	appendcOFile(fp,*p);
-	p++;
+        /* break up lines biggger than 75 chars */
+        if(count >=74){
+		count=0;
+		appendsOFile(fp,"=\n");
 	}
+	
+	/* escape any non ASCII characters and '=' as per rfc1521 */
+	if (*p<= 0x1f || *p >=0x7f || *p == '=' ) {
+		sprintf(buf,"=%02X",(unsigned char)*p);
+		appendsOFile(fp,buf); 
+		count+=3; 
+	} else {
+		appendcOFile(fp,*p);	
+		count++; 
+	}
+	p++;
+    }
 }
 
 
 
 static void writeVObject_(OFile *fp, VObject *o);
 
-static void writeValue(OFile *fp, VObject *o, unsigned long size)
+static void writeValue(OFile *fp, VObject *o, unsigned long size,int quote)
 {
     if (o == 0) return;
     switch (VALUE_TYPE(o)) {
 	case VCVT_USTRINGZ: {
 	    char *s = fakeCString(USTRINGZ_VALUE_OF(o));
-	    writeQPString(fp, s);
+	    if(quote) writeQPString(fp, s);
+	    else writeString(fp,s);
 	    deleteStr(s);
 	    break;
 	    }
 	case VCVT_STRINGZ: {
-	    writeQPString(fp, STRINGZ_VALUE_OF(o));
+	    if(quote) writeQPString(fp, STRINGZ_VALUE_OF(o));
+	    else writeString(fp,STRINGZ_VALUE_OF(o));
 	    break;
 	    }
 	case VCVT_UINT: {
@@ -1216,7 +1249,7 @@ static void writeAttrValue(OFile *fp, VObject *o)
 	appendcOFile(fp,';');
     if (VALUE_TYPE(o)) {
 	appendcOFile(fp,'=');
-	writeValue(fp,o,0);
+	writeValue(fp,o,0,0);
 	}
 }
 
@@ -1246,6 +1279,7 @@ static int inList(const char **list, const char *s)
 
 static void writeProp(OFile *fp, VObject *o)
 {
+    int isQuoted=0;
     if (NAME_OF(o)) {
 	struct PreDefProp *pi;
 	VObjectIterator t;
@@ -1267,6 +1301,8 @@ static void writeProp(OFile *fp, VObject *o)
 	    s = NAME_OF(eachProp);
 	    if (stricmp(VCGroupingProp,s) && !inList(fields_,s))
 		writeAttrValue(fp,eachProp);
+	    if (stricmp(VCQPProp,s)==0 || stricmp(VCQuotedPrintableProp,s)==0)
+		 isQuoted=1;
 	    }
 	if (fields_) {
 	    int i = 0, n = 0;
@@ -1281,7 +1317,7 @@ static void writeProp(OFile *fp, VObject *o)
 		}
 	    fields = fields_;
 	    for (i=0;i<n;i++) {
-		writeValue(fp,isAPropertyOf(o,*fields),0);
+		writeValue(fp,isAPropertyOf(o,*fields),0,isQuoted);
 		fields++;
 		if (i<(n-1)) appendcOFile(fp,';');
 		}
@@ -1293,7 +1329,7 @@ static void writeProp(OFile *fp, VObject *o)
         VObject *p = isAPropertyOf(o,VCDataSizeProp);
 	if (p) size = LONG_VALUE_OF(p);
 	appendcOFile(fp,':');
-	writeValue(fp,o,size);
+	writeValue(fp,o,size,isQuoted);
 	}
 
     appendcOFile(fp,'\n');
@@ -1411,7 +1447,12 @@ DLLEXPORT(char*) fakeCString(const wchar_t *u)
 {
     char *s, *t;
     int len = uStrLen(u) + 1;
+
+    if (!u)
+	return strdup("");
+    
     t = s = (char*)malloc(len);
+
     while (*u) {
 	if (*u == (wchar_t)0x2028)
 	    *t = '\n';
